// SAL_VERSION=5.0.1 XML_VERSION=6.2.1
module MTMount {
struct Auxiliary_Boxes_d779f34f {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	Status_TMA_AZ_PD_CBT_0001; // @Metadata=(Units="unitless",Description="Status_TMA_AZ_PD_CBT_0001")
	  string	Status_TMA_EL_PD_CBT_0001; // @Metadata=(Units="unitless",Description="Status_TMA_EL_PD_CBT_0001")
	  string	Status_TMA_EL_PD_CBT_0002; // @Metadata=(Units="unitless",Description="Status_TMA_EL_PD_CBT_0002")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Auxiliary_Boxes_d779f34f 
struct Auxliary_Cabinet_Azimuth_7a65c759 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	Auxiliar_Azimuth_Cabinet_Status; // @Metadata=(Units="unitless",Description="Auxiliar_Azimuth_Cabinet_Status")
	  double	Auxiliar_Azimuth_Cabinet_External_Temperature; // @Metadata=(Units="deg_C",Description="Auxiliar_Azimuth_Cabinet_External_Temperature")
	  double	Auxiliar_Azimuth_Cabinet_Internal_Temperature_1; // @Metadata=(Units="deg_C",Description="Auxiliar_Azimuth_Cabinet_Internal_Temperature_1")
	  double	Auxiliar_Azimuth_Cabinet_Internal_Temperature_2; // @Metadata=(Units="deg_C",Description="Auxiliar_Azimuth_Cabinet_Internal_Temperature_2")
	  double	Auxiliar_Azimuth_Cabinet_Setpoint_Temperature; // @Metadata=(Units="deg_C",Description="Auxiliar_Azimuth_Cabinet_Setpoint_Temperature")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Auxliary_Cabinet_Azimuth_7a65c759 
struct Azimuth_5867fb25 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	Azimuth_Status; // @Metadata=(Units="unitless",Description="Azimuth_Status")
	  double	Azimuth_Angle_Actual; // @Metadata=(Units="deg",Description="Azimuth_Angle_Actual")
	  double	Azimuth_Angle_Set; // @Metadata=(Units="deg",Description="Azimuth_Angle_Set")
	  double	Azimuth_Aceleration_Actual; // @Metadata=(Units="deg/second^2",Description="Azimuth_Aceleration_Actual")
	  double	Azimuth_Velocity_Set; // @Metadata=(Units="deg/second",Description="Azimuth_Velocity_Set")
	  double	Azimuth_Velocity_Actual; // @Metadata=(Units="deg/second",Description="Azimuth_Velocity_Actual")
	  double	Azimuth_Torque_Actual; // @Metadata=(Units="unitless",Description="Azimuth_Torque_Actual")
	  boolean	Azimuth_Positive_Software_limit; // @Metadata=(Units="unitless",Description="Azimuth_Positive_Software_limit")
	  boolean	Azimuth_Negative_Software_limit; // @Metadata=(Units="unitless",Description="Azimuth_Negative_Software_limit")
	  boolean	Azimuth_Positive_Power_Off_switch; // @Metadata=(Units="unitless",Description="Azimuth_Positive_Power_Off_switch")
	  boolean	Azimuth_Negative_Power_Off_switch; // @Metadata=(Units="unitless",Description="Azimuth_Negative_Power_Off_switch")
	  boolean	Azimuth_Positive_Directional_limit_switch; // @Metadata=(Units="unitless",Description="Azimuth_Positive_Directional_limit_switch")
	  boolean	Azimuth_Negative_Directional_limit_switch; // @Metadata=(Units="unitless",Description="Azimuth_Negative_Directional_limit_switch")
	  boolean	Azimuth_Positive_Adjustable_Software_limit; // @Metadata=(Units="unitless",Description="Azimuth_Positive_Adjustable_Software_limit")
	  boolean	Azimuth_Negative_Adjustable_Software_limit; // @Metadata=(Units="unitless",Description="Azimuth_Negative_Adjustable_Software_limit")
	  string	Azimuth_Interlocks; // @Metadata=(Units="unitless",Description="Azimuth_Interlocks")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Azimuth_5867fb25 
struct Azimuth_Cable_Wrap_2ea8d0f3 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	ACW_Status; // @Metadata=(Units="unitless",Description="ACW_Status")
	  string	ACW_Status_Drive_1; // @Metadata=(Units="unitless",Description="ACW_Status_Drive_1")
	  string	ACW_Status_Drive_2; // @Metadata=(Units="unitless",Description="ACW_Status_Drive_2")
	  double	ACW_Current_Drive_1; // @Metadata=(Units="unitless",Description="ACW_Current_Drive_1")
	  double	ACW_Current_Drive_2; // @Metadata=(Units="unitless",Description="ACW_Current_Drive_2")
	  double	ACW_AngleDif_Actual; // @Metadata=(Units="unitless",Description="ACW_AngleDif_Actual")
	  double	ACW_AngleDif_ActualLVDT; // @Metadata=(Units="unitless",Description="ACW_AngleDif_ActualLVDT")
	  double	ACW_Angle_Setpoint; // @Metadata=(Units="deg",Description="ACW_Angle_Setpoint")
	  boolean	ACW_Positive_Power_Off_switch; // @Metadata=(Units="unitless",Description="ACW_Positive_Power_Off_switch")
	  boolean	ACW_Negative_Power_Off_switch; // @Metadata=(Units="unitless",Description="ACW_Negative_Power_Off_switch")
	  string	ACW_Interlocks; // @Metadata=(Units="unitless",Description="ACW_Interlocks")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Azimuth_Cable_Wrap_2ea8d0f3 
struct Azimuth_Drives_c1a8c8fb {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	Azimuth_Status_Drive_1; // @Metadata=(Units="unitless",Description="Azimuth_Status_Drive_1")
	  string	Azimuth_Status_Drive_2; // @Metadata=(Units="unitless",Description="Azimuth_Status_Drive_2")
	  string	Azimuth_Status_Drive_3; // @Metadata=(Units="unitless",Description="Azimuth_Status_Drive_3")
	  string	Azimuth_Status_Drive_4; // @Metadata=(Units="unitless",Description="Azimuth_Status_Drive_4")
	  string	Azimuth_Status_Drive_5; // @Metadata=(Units="unitless",Description="Azimuth_Status_Drive_5")
	  string	Azimuth_Status_Drive_6; // @Metadata=(Units="unitless",Description="Azimuth_Status_Drive_6")
	  string	Azimuth_Status_Drive_7; // @Metadata=(Units="unitless",Description="Azimuth_Status_Drive_7")
	  string	Azimuth_Status_Drive_8; // @Metadata=(Units="unitless",Description="Azimuth_Status_Drive_8")
	  string	Azimuth_Status_Drive_9; // @Metadata=(Units="unitless",Description="Azimuth_Status_Drive_9")
	  string	Azimuth_Status_Drive_10; // @Metadata=(Units="unitless",Description="Azimuth_Status_Drive_10")
	  string	Azimuth_Status_Drive_11; // @Metadata=(Units="unitless",Description="Azimuth_Status_Drive_11")
	  string	Azimuth_Status_Drive_12; // @Metadata=(Units="unitless",Description="Azimuth_Status_Drive_12")
	  string	Azimuth_Status_Drive_13; // @Metadata=(Units="unitless",Description="Azimuth_Status_Drive_13")
	  string	Azimuth_Status_Drive_14; // @Metadata=(Units="unitless",Description="Azimuth_Status_Drive_14")
	  string	Azimuth_Status_Drive_15; // @Metadata=(Units="unitless",Description="Azimuth_Status_Drive_15")
	  string	Azimuth_Status_Drive_16; // @Metadata=(Units="unitless",Description="Azimuth_Status_Drive_16")
	  double	Azimuth_Current_Drive_1; // @Metadata=(Units="A",Description="Azimuth_Current_Drive_1")
	  double	Azimuth_Current_Drive_2; // @Metadata=(Units="A",Description="Azimuth_Current_Drive_2")
	  double	Azimuth_Current_Drive_3; // @Metadata=(Units="A",Description="Azimuth_Current_Drive_3")
	  double	Azimuth_Current_Drive_4; // @Metadata=(Units="A",Description="Azimuth_Current_Drive_4")
	  double	Azimuth_Current_Drive_5; // @Metadata=(Units="A",Description="Azimuth_Current_Drive_5")
	  double	Azimuth_Current_Drive_6; // @Metadata=(Units="A",Description="Azimuth_Current_Drive_6")
	  double	Azimuth_Current_Drive_7; // @Metadata=(Units="A",Description="Azimuth_Current_Drive_7")
	  double	Azimuth_Current_Drive_8; // @Metadata=(Units="A",Description="Azimuth_Current_Drive_8")
	  double	Azimuth_Current_Drive_9; // @Metadata=(Units="A",Description="Azimuth_Current_Drive_9")
	  double	Azimuth_Current_Drive_10; // @Metadata=(Units="A",Description="Azimuth_Current_Drive_10")
	  double	Azimuth_Current_Drive_11; // @Metadata=(Units="A",Description="Azimuth_Current_Drive_11")
	  double	Azimuth_Current_Drive_12; // @Metadata=(Units="A",Description="Azimuth_Current_Drive_12")
	  double	Azimuth_Current_Drive_13; // @Metadata=(Units="A",Description="Azimuth_Current_Drive_13")
	  double	Azimuth_Current_Drive_14; // @Metadata=(Units="A",Description="Azimuth_Current_Drive_14")
	  double	Azimuth_Current_Drive_15; // @Metadata=(Units="A",Description="Azimuth_Current_Drive_15")
	  double	Azimuth_Current_Drive_16; // @Metadata=(Units="A",Description="Azimuth_Current_Drive_16")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Azimuth_Drives_c1a8c8fb 
struct Azimuth_Drives_Thermal_252ccc07 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	Azimuth_Thermal_Status_Group_1; // @Metadata=(Units="unitless",Description="Azimuth_Thermal_Status_Group_1")
	  string	Azimuth_Thermal_Status_Group_2; // @Metadata=(Units="unitless",Description="Azimuth_Thermal_Status_Group_2")
	  string	Azimuth_Thermal_Status_Group_3; // @Metadata=(Units="unitless",Description="Azimuth_Thermal_Status_Group_3")
	  string	Azimuth_Thermal_Status_Group_4; // @Metadata=(Units="unitless",Description="Azimuth_Thermal_Status_Group_4")
	  double	Azimuth_Surface_Temperature_Motor_1; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Motor_1")
	  double	Azimuth_Surface_Temperature_Motor_2; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Motor_2")
	  double	Azimuth_Surface_Temperature_Motor_3; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Motor_3")
	  double	Azimuth_Surface_Temperature_Motor_4; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Motor_4")
	  double	Azimuth_Surface_Temperature_Motor_5; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Motor_5")
	  double	Azimuth_Surface_Temperature_Motor_6; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Motor_6")
	  double	Azimuth_Surface_Temperature_Motor_7; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Motor_7")
	  double	Azimuth_Surface_Temperature_Motor_8; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Motor_8")
	  double	Azimuth_Surface_Temperature_Motor_9; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Motor_9")
	  double	Azimuth_Surface_Temperature_Motor_10; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Motor_10")
	  double	Azimuth_Surface_Temperature_Motor_11; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Motor_11")
	  double	Azimuth_Surface_Temperature_Motor_12; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Motor_12")
	  double	Azimuth_Surface_Temperature_Motor_13; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Motor_13")
	  double	Azimuth_Surface_Temperature_Motor_14; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Motor_14")
	  double	Azimuth_Surface_Temperature_Motor_15; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Motor_15")
	  double	Azimuth_Surface_Temperature_Motor_16; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Motor_16")
	  double	Azimuth_Surface_Temperature_Drive_1; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Drive_1")
	  double	Azimuth_Surface_Temperature_Drive_2; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Drive_2")
	  double	Azimuth_Surface_Temperature_Drive_3; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Drive_3")
	  double	Azimuth_Surface_Temperature_Drive_4; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Drive_4")
	  double	Azimuth_Surface_Temperature_Drive_5; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Drive_5")
	  double	Azimuth_Surface_Temperature_Drive_6; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Drive_6")
	  double	Azimuth_Surface_Temperature_Drive_7; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Drive_7")
	  double	Azimuth_Surface_Temperature_Drive_8; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Drive_8")
	  double	Azimuth_Surface_Temperature_Drive_9; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Drive_9")
	  double	Azimuth_Surface_Temperature_Drive_10; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Drive_10")
	  double	Azimuth_Surface_Temperature_Drive_11; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Drive_11")
	  double	Azimuth_Surface_Temperature_Drive_12; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Drive_12")
	  double	Azimuth_Surface_Temperature_Drive_13; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Drive_13")
	  double	Azimuth_Surface_Temperature_Drive_14; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Drive_14")
	  double	Azimuth_Surface_Temperature_Drive_15; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Drive_15")
	  double	Azimuth_Surface_Temperature_Drive_16; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Drive_16")
	  double	Azimuth_Surface_Temperature_Setpoint_Group_1; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Setpoint_Group_1")
	  double	Azimuth_Surface_Temperature_Setpoint_Group_2; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Setpoint_Group_2")
	  double	Azimuth_Surface_Temperature_Setpoint_Group_3; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Setpoint_Group_3")
	  double	Azimuth_Surface_Temperature_Setpoint_Group_4; // @Metadata=(Units="deg_C",Description="Azimuth_Surface_Temperature_Setpoint_Group_4")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Azimuth_Drives_Thermal_252ccc07 
struct Balancing_1a1e225c {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	Balancing_Status; // @Metadata=(Units="unitless",Description="Balancing_Status")
	  double	Balancing_Actual_Position_Drive_1; // @Metadata=(Units="unitless",Description="Balancing_Actual_Position_Drive_1")
	  double	Balancing_Actual_Position_Drive_2; // @Metadata=(Units="unitless",Description="Balancing_Actual_Position_Drive_2")
	  double	Balancing_Actual_Position_Drive_3; // @Metadata=(Units="unitless",Description="Balancing_Actual_Position_Drive_3")
	  double	Balancing_Actual_Position_Drive_4; // @Metadata=(Units="unitless",Description="Balancing_Actual_Position_Drive_4")
	  boolean	Balancing_Positive_Limit_Switch_Drive_1; // @Metadata=(Units="unitless",Description="Balancing_Positive_Limit_Switch_Drive_1")
	  boolean	Balancing_Positive_Limit_Switch_Drive_2; // @Metadata=(Units="unitless",Description="Balancing_Positive_Limit_Switch_Drive_2")
	  boolean	Balancing_Positive_Limit_Switch_Drive_3; // @Metadata=(Units="unitless",Description="Balancing_Positive_Limit_Switch_Drive_3")
	  boolean	Balancing_Positive_Limit_Switch_Drive_4; // @Metadata=(Units="unitless",Description="Balancing_Positive_Limit_Switch_Drive_4")
	  boolean	Balancing_Negative_Limit_Switch_Drive_1; // @Metadata=(Units="unitless",Description="Balancing_Negative_Limit_Switch_Drive_1")
	  boolean	Balancing_Negative_Limit_Switch_Drive_2; // @Metadata=(Units="unitless",Description="Balancing_Negative_Limit_Switch_Drive_2")
	  boolean	Balancing_Negative_Limit_Switch_Drive_3; // @Metadata=(Units="unitless",Description="Balancing_Negative_Limit_Switch_Drive_3")
	  boolean	Balancing_Negative_Limit_Switch_Drive_4; // @Metadata=(Units="unitless",Description="Balancing_Negative_Limit_Switch_Drive_4")
	  string	Balancing_Interlocks; // @Metadata=(Units="unitless",Description="Balancing_Interlocks")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Balancing_1a1e225c 
struct Balancing_Drives_6f86eb34 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	Balancing_Status_Drive_1; // @Metadata=(Units="unitless",Description="Balancing_Status_Drive_1")
	  string	Balancing_Status_Drive_2; // @Metadata=(Units="unitless",Description="Balancing_Status_Drive_2")
	  string	Balancing_Status_Drive_3; // @Metadata=(Units="unitless",Description="Balancing_Status_Drive_3")
	  string	Balancing_Status_Drive_4; // @Metadata=(Units="unitless",Description="Balancing_Status_Drive_4")
	  double	Balancing_Current_Drive_1; // @Metadata=(Units="A",Description="Balancing_Current_Drive_1")
	  double	Balancing_Current_Drive_2; // @Metadata=(Units="A",Description="Balancing_Current_Drive_2")
	  double	Balancing_Current_Drive_3; // @Metadata=(Units="A",Description="Balancing_Current_Drive_3")
	  double	Balancing_Current_Drive_4; // @Metadata=(Units="A",Description="Balancing_Current_Drive_4")
	  double	Balancing_Position_Set_Drive_1; // @Metadata=(Units="unitless",Description="Balancing_Position_Set_Drive_1")
	  double	Balancing_Position_Set_Drive_2; // @Metadata=(Units="unitless",Description="Balancing_Position_Set_Drive_2")
	  double	Balancing_Position_Set_Drive_3; // @Metadata=(Units="unitless",Description="Balancing_Position_Set_Drive_3")
	  double	Balancing_Position_Set_Drive_4; // @Metadata=(Units="unitless",Description="Balancing_Position_Set_Drive_4")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Balancing_Drives_6f86eb34 
struct Camera_Cable_Wrap_40e3e4c3 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	CCW_Status; // @Metadata=(Units="unitless",Description="CCW_Status")
	  string	CCW_Status_Drive_1; // @Metadata=(Units="unitless",Description="CCW_Status_Drive_1")
	  string	CCW_Status_Drive_2; // @Metadata=(Units="unitless",Description="CCW_Status_Drive_2")
	  double	CameraRotatorPosition; // @Metadata=(Units="deg",Description="CameraRotatorPosition")
	  double	CCW_Angle_1; // @Metadata=(Units="deg",Description="CCW_Angle_1")
	  double	CCW_Angle_2; // @Metadata=(Units="deg",Description="CCW_Angle_2")
	  double	CCW_Camera_Position; // @Metadata=(Units="deg",Description="CCW_Camera_Position")
	  double	CCW_Speed_1; // @Metadata=(Units="deg/second",Description="CCW_Speed_1")
	  double	CCW_Speed_2; // @Metadata=(Units="deg/second",Description="CCW_Speed_2")
	  double	CCW_Current_1; // @Metadata=(Units="A",Description="CCW_Current_1")
	  double	CCW_Current_2; // @Metadata=(Units="A",Description="CCW_Current_2")
	  boolean	CCW_Positive_Directional_limit_switch; // @Metadata=(Units="unitless",Description="CCW_Positive_Directional_limit_switch")
	  boolean	CCW_Negative_Directional_limit_switch; // @Metadata=(Units="unitless",Description="CCW_Negative_Directional_limit_switch")
	  string	CCW_Interlocks; // @Metadata=(Units="unitless",Description="CCW_Interlocks")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Camera_Cable_Wrap_40e3e4c3 
struct Compressed_Air_e7d3cb38 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	TMA_AZ_CP_CPM_0001; // @Metadata=(Units="unitless",Description="TMA_AZ_CP_CPM_0001")
	  double	TMA_AZ_CP_CPM_0002; // @Metadata=(Units="unitless",Description="TMA_AZ_CP_CPM_0002")
	  double	TMA_EL_CP_CPM_0001; // @Metadata=(Units="unitless",Description="TMA_EL_CP_CPM_0001")
	  double	TMA_EL_CP_CPM_0002; // @Metadata=(Units="unitless",Description="TMA_EL_CP_CPM_0002")
	  double	TMA_PI_CP_CPM_0101; // @Metadata=(Units="unitless",Description="TMA_PI_CP_CPM_0101")
	  double	TMA_PI_CP_CTM_0101; // @Metadata=(Units="unitless",Description="TMA_PI_CP_CTM_0101")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Compressed_Air_e7d3cb38 
struct Cooling_62c4e0fe {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	TMA_AZ_GW_CPM_0001; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0001")
	  double	TMA_AZ_GW_CPM_0002; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0002")
	  double	TMA_AZ_GW_CPM_0021; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0021")
	  double	TMA_AZ_GW_CPM_0022; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0022")
	  double	TMA_AZ_GW_CTM_0001; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CTM_0001")
	  double	TMA_AZ_GW_CTM_0002; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CTM_0002")
	  double	TMA_AZ_GW_CTM_0021; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CTM_0021")
	  double	TMA_AZ_GW_CTM_0022; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CTM_0022")
	  double	TMA_PI_GW_CPM_0101; // @Metadata=(Units="unitless",Description="TMA_PI_GW_CPM_0101")
	  double	TMA_PI_GW_CPM_0102; // @Metadata=(Units="unitless",Description="TMA_PI_GW_CPM_0102")
	  double	TMA_PI_GW_CTM_0101; // @Metadata=(Units="unitless",Description="TMA_PI_GW_CTM_0101")
	  double	TMA_PI_GW_CTM_0102; // @Metadata=(Units="unitless",Description="TMA_PI_GW_CTM_0102")
	  double	TMA_AZ_GW_CPM_0003; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0003")
	  double	TMA_AZ_GW_CPM_0004; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0004")
	  double	TMA_AZ_GW_CPM_0005; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0005")
	  double	TMA_AZ_GW_CPM_0006; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0006")
	  double	TMA_AZ_GW_CPM_0007; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0007")
	  double	TMA_AZ_GW_CPM_0008; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0008")
	  double	TMA_AZ_GW_CPM_0009; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0009")
	  double	TMA_AZ_GW_CPM_0010; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0010")
	  double	TMA_AZ_GW_CPM_0011; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0011")
	  double	TMA_AZ_GW_CPM_0012; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0012")
	  double	TMA_AZ_GW_CPM_0013; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0013")
	  double	TMA_AZ_GW_CPM_0014; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0014")
	  double	TMA_AZ_GW_CPM_0015; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0015")
	  double	TMA_AZ_GW_CPM_0016; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0016")
	  double	TMA_AZ_GW_CPM_0017; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0017")
	  double	TMA_AZ_GW_CPM_0018; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0018")
	  double	TMA_AZ_GW_CPM_0019; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0019")
	  double	TMA_AZ_GW_CPM_0020; // @Metadata=(Units="unitless",Description="TMA_AZ_GW_CPM_0020")
	  double	TMA_EL_GW_CPM_0001; // @Metadata=(Units="unitless",Description="TMA_EL_GW_CPM_0001")
	  double	TMA_EL_GW_CPM_0002; // @Metadata=(Units="unitless",Description="TMA_EL_GW_CPM_0002")
	  double	TMA_EL_GW_CTM_0001; // @Metadata=(Units="unitless",Description="TMA_EL_GW_CTM_0001")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Cooling_62c4e0fe 
struct Deployable_Platforms_8c75963b {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	DP_Status; // @Metadata=(Units="unitless",Description="DP_Status")
	  string	DP_Status_Drive_1; // @Metadata=(Units="unitless",Description="DP_Status_Drive_1")
	  string	DP_Status_Drive_2; // @Metadata=(Units="unitless",Description="DP_Status_Drive_2")
	  double	DP_Current_Drive_2; // @Metadata=(Units="A",Description="DP_Current_Drive_2")
	  double	DP_Current_Drive_1; // @Metadata=(Units="A",Description="DP_Current_Drive_1")
	  double	DP_Position_Set_Section_1; // @Metadata=(Units="m",Description="DP_Position_Set_Section_1")
	  double	DP_Position_Set_Section_2; // @Metadata=(Units="m",Description="DP_Position_Set_Section_2")
	  double	DP_Position_Actual_Section_1; // @Metadata=(Units="m",Description="DP_Position_Actual_Section_1")
	  double	DP_Position_Actual_Section_2; // @Metadata=(Units="m",Description="DP_Position_Actual_Section_2")
	  boolean	DP_Extended_Directional_Limit_Switch_Section_1; // @Metadata=(Units="unitless",Description="DP_Extended_Directional_Limit_Switch_Section_1")
	  boolean	DP_Extended_Directional_Limit_Switch_Section_2; // @Metadata=(Units="unitless",Description="DP_Extended_Directional_Limit_Switch_Section_2")
	  boolean	DP_Retracted_Directional_Limit_Switch_Section_1; // @Metadata=(Units="unitless",Description="DP_Retracted_Directional_Limit_Switch_Section_1")
	  boolean	DP_Retracted_Directional_Limit_Switch_Section_2; // @Metadata=(Units="unitless",Description="DP_Retracted_Directional_Limit_Switch_Section_2")
	  boolean	DP_Platform_1_Extension_1_Locked_Limit_Switch; // @Metadata=(Units="unitless",Description="DP_Platform_1_Extension_1_Locked_Limit_Switch")
	  boolean	DP_Platform_1_Extension_1_Retracted_Limit_Switch; // @Metadata=(Units="unitless",Description="DP_Platform_1_Extension_1_Retracted_Limit_Switch")
	  boolean	DP_Platform_1_Extension_2_Locked_Limit_Switch; // @Metadata=(Units="unitless",Description="DP_Platform_1_Extension_2_Locked_Limit_Switch")
	  boolean	DP_Platform_1_Extension_2_Retracted_Limit_Switch; // @Metadata=(Units="unitless",Description="DP_Platform_1_Extension_2_Retracted_Limit_Switch")
	  boolean	DP_Platform_2_Extension_1_Locked_Limit_Switch; // @Metadata=(Units="unitless",Description="DP_Platform_2_Extension_1_Locked_Limit_Switch")
	  boolean	DP_Platform_2_Extension_1_Retracted_Limit_Switch; // @Metadata=(Units="unitless",Description="DP_Platform_2_Extension_1_Retracted_Limit_Switch")
	  boolean	DP_Platform_2_Extension_2_Locked_Limit_Switch; // @Metadata=(Units="unitless",Description="DP_Platform_2_Extension_2_Locked_Limit_Switch")
	  boolean	DP_Platform_2_Extension_2_Retracted_Limit_Switch; // @Metadata=(Units="unitless",Description="DP_Platform_2_Extension_2_Retracted_Limit_Switch")
	  string	DP_Interlocks; // @Metadata=(Units="unitless",Description="DP_Interlocks")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Deployable_Platforms_8c75963b 
struct Dynalene_Cooling_9ad5c015 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	TMA_AZ_DY_CPM_0001; // @Metadata=(Units="unitless",Description="TMA_AZ_DY_CPM_0001")
	  double	TMA_AZ_DY_CPM_0002; // @Metadata=(Units="unitless",Description="TMA_AZ_DY_CPM_0002")
	  double	TMA_AZ_DY_CTM_0001; // @Metadata=(Units="unitless",Description="TMA_AZ_DY_CTM_0001")
	  double	TMA_AZ_DY_CTM_0002; // @Metadata=(Units="unitless",Description="TMA_AZ_DY_CTM_0002")
	  double	TMA_AZ_EL_CPM_0001; // @Metadata=(Units="unitless",Description="TMA_AZ_EL_CPM_0001")
	  double	TMA_AZ_EL_CPM_0007; // @Metadata=(Units="unitless",Description="TMA_AZ_EL_CPM_0007")
	  double	TMA_PI_DY_CPM_0101; // @Metadata=(Units="unitless",Description="TMA_PI_DY_CPM_0101")
	  double	TMA_PI_DY_CPM_0102; // @Metadata=(Units="unitless",Description="TMA_PI_DY_CPM_0102")
	  double	TMA_PI_DY_CTM_0101; // @Metadata=(Units="unitless",Description="TMA_PI_DY_CTM_0101")
	  double	TMA_PI_DY_CTM_0102; // @Metadata=(Units="unitless",Description="TMA_PI_DY_CTM_0102")
	  double	TMA_AZ_EL_CPM_0002; // @Metadata=(Units="unitless",Description="TMA_AZ_EL_CPM_0002")
	  double	TMA_AZ_EL_CPM_0003; // @Metadata=(Units="unitless",Description="TMA_AZ_EL_CPM_0003")
	  double	TMA_AZ_EL_CPM_0004; // @Metadata=(Units="unitless",Description="TMA_AZ_EL_CPM_0004")
	  double	TMA_AZ_EL_CPM_0005; // @Metadata=(Units="unitless",Description="TMA_AZ_EL_CPM_0005")
	  double	TMA_AZ_EL_CPM_0006; // @Metadata=(Units="unitless",Description="TMA_AZ_EL_CPM_0006")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Dynalene_Cooling_9ad5c015 
struct Elevation_0093c7ae {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	Elevation_Status; // @Metadata=(Units="unitless",Description="Elevation_Status")
	  double	Elevation_Angle_Actual; // @Metadata=(Units="unitless",Description="Elevation_Angle_Actual")
	  double	Elevation_Angle_Set; // @Metadata=(Units="deg",Description="Elevation_Angle_Set")
	  double	Elevation_Aceleration_Actual; // @Metadata=(Units="deg/second^2",Description="Elevation_Aceleration_Actual")
	  double	Elevation_Velocity_Set; // @Metadata=(Units="deg/second",Description="Elevation_Velocity_Set")
	  double	Elevation_Velocity_Actual; // @Metadata=(Units="deg/second",Description="Elevation_Velocity_Actual")
	  double	Elevation_Torque_Actual; // @Metadata=(Units="N / m",Description="Elevation_Torque_Actual")
	  boolean	Elevation_Positive_Software_limit; // @Metadata=(Units="unitless",Description="Elevation_Positive_Software_limit")
	  boolean	Elevation_Negative_Software_limit; // @Metadata=(Units="unitless",Description="Elevation_Negative_Software_limit")
	  boolean	Elevation_Positive_Power_Off_switch; // @Metadata=(Units="unitless",Description="Elevation_Positive_Power_Off_switch")
	  boolean	Elevation_Negative_Power_Off_switch; // @Metadata=(Units="unitless",Description="Elevation_Negative_Power_Off_switch")
	  boolean	Elevation_Positive_Directional_limit_switch; // @Metadata=(Units="unitless",Description="Elevation_Positive_Directional_limit_switch")
	  boolean	Elevation_Negative_Directional_limit_switch; // @Metadata=(Units="unitless",Description="Elevation_Negative_Directional_limit_switch")
	  boolean	Elevation_Positive_Adjustable_Software_limit; // @Metadata=(Units="unitless",Description="Elevation_Positive_Adjustable_Software_limit")
	  boolean	Elevation_Negative_Adjustable_Software_limit; // @Metadata=(Units="unitless",Description="Elevation_Negative_Adjustable_Software_limit")
	  boolean	Elevation_Positive_Operational_Directional_limit_switch; // @Metadata=(Units="unitless",Description="Elevation_Positive_Operational_Directional_limit_switch")
	  boolean	Elevation_Negative_Operational_Directional_limit_switch; // @Metadata=(Units="unitless",Description="Elevation_Negative_Operational_Directional_limit_switch")
	  string	Elevation_Interlocks; // @Metadata=(Units="unitless",Description="Elevation_Interlocks")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Elevation_0093c7ae 
struct Elevation_Drives_f43f6995 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	Elevation_Status_Drive_1; // @Metadata=(Units="unitless",Description="Elevation_Status_Drive_1")
	  string	Elevation_Status_Drive_2; // @Metadata=(Units="unitless",Description="Elevation_Status_Drive_2")
	  string	Elevation_Status_Drive_3; // @Metadata=(Units="unitless",Description="Elevation_Status_Drive_3")
	  string	Elevation_Status_Drive_4; // @Metadata=(Units="unitless",Description="Elevation_Status_Drive_4")
	  string	Elevation_Status_Drive_5; // @Metadata=(Units="unitless",Description="Elevation_Status_Drive_5")
	  string	Elevation_Status_Drive_6; // @Metadata=(Units="unitless",Description="Elevation_Status_Drive_6")
	  string	Elevation_Status_Drive_7; // @Metadata=(Units="unitless",Description="Elevation_Status_Drive_7")
	  string	Elevation_Status_Drive_8; // @Metadata=(Units="unitless",Description="Elevation_Status_Drive_8")
	  string	Elevation_Status_Drive_9; // @Metadata=(Units="unitless",Description="Elevation_Status_Drive_9")
	  string	Elevation_Status_Drive_10; // @Metadata=(Units="unitless",Description="Elevation_Status_Drive_10")
	  string	Elevation_Status_Drive_11; // @Metadata=(Units="unitless",Description="Elevation_Status_Drive_11")
	  string	Elevation_Status_Drive_12; // @Metadata=(Units="unitless",Description="Elevation_Status_Drive_12")
	  double	Elevation_Current_Drive_1; // @Metadata=(Units="unitless",Description="Elevation_Current_Drive_1")
	  double	Elevation_Current_Drive_2; // @Metadata=(Units="unitless",Description="Elevation_Current_Drive_2")
	  double	Elevation_Current_Drive_3; // @Metadata=(Units="unitless",Description="Elevation_Current_Drive_3")
	  double	Elevation_Current_Drive_4; // @Metadata=(Units="unitless",Description="Elevation_Current_Drive_4")
	  double	Elevation_Current_Drive_5; // @Metadata=(Units="unitless",Description="Elevation_Current_Drive_5")
	  double	Elevation_Current_Drive_6; // @Metadata=(Units="unitless",Description="Elevation_Current_Drive_6")
	  double	Elevation_Current_Drive_7; // @Metadata=(Units="unitless",Description="Elevation_Current_Drive_7")
	  double	Elevation_Current_Drive_8; // @Metadata=(Units="unitless",Description="Elevation_Current_Drive_8")
	  double	Elevation_Current_Drive_9; // @Metadata=(Units="unitless",Description="Elevation_Current_Drive_9")
	  double	Elevation_Current_Drive_10; // @Metadata=(Units="unitless",Description="Elevation_Current_Drive_10")
	  double	Elevation_Current_Drive_11; // @Metadata=(Units="unitless",Description="Elevation_Current_Drive_11")
	  double	Elevation_Current_Drive_12; // @Metadata=(Units="unitless",Description="Elevation_Current_Drive_12")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Elevation_Drives_f43f6995 
struct Elevation_Drives_Thermal_dbb4b986 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	Elevation_Thermal_Status_Group_1; // @Metadata=(Units="unitless",Description="Elevation_Thermal_Status_Group_1")
	  string	Elevation_Thermal_Status_Group_2; // @Metadata=(Units="unitless",Description="Elevation_Thermal_Status_Group_2")
	  double	Elevation_Surface_Temperature_Motor_1; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Motor_1")
	  double	Elevation_Surface_Temperature_Motor_2; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Motor_2")
	  double	Elevation_Surface_Temperature_Motor_3; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Motor_3")
	  double	Elevation_Surface_Temperature_Motor_4; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Motor_4")
	  double	Elevation_Surface_Temperature_Motor_5; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Motor_5")
	  double	Elevation_Surface_Temperature_Motor_6; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Motor_6")
	  double	Elevation_Surface_Temperature_Motor_7; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Motor_7")
	  double	Elevation_Surface_Temperature_Motor_8; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Motor_8")
	  double	Elevation_Surface_Temperature_Motor_9; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Motor_9")
	  double	Elevation_Surface_Temperature_Motor_10; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Motor_10")
	  double	Elevation_Surface_Temperature_Motor_11; // @Metadata=(Units="unitless",Description="Elevation_Surface_Temperature_Motor_11")
	  double	Elevation_Surface_Temperature_Motor_12; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Motor_12")
	  double	Elevation_Surface_Temperature_Drive_1; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Drive_1")
	  double	Elevation_Surface_Temperature_Drive_2; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Drive_2")
	  double	Elevation_Surface_Temperature_Drive_3; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Drive_3")
	  double	Elevation_Surface_Temperature_Drive_4; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Drive_4")
	  double	Elevation_Surface_Temperature_Drive_5; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Drive_5")
	  double	Elevation_Surface_Temperature_Drive_6; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Drive_6")
	  double	Elevation_Surface_Temperature_Drive_7; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Drive_7")
	  double	Elevation_Surface_Temperature_Drive_8; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Drive_8")
	  double	Elevation_Surface_Temperature_Drive_9; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Drive_9")
	  double	Elevation_Surface_Temperature_Drive_10; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Drive_10")
	  double	Elevation_Surface_Temperature_Drive_11; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Drive_11")
	  double	Elevation_Surface_Temperature_Drive_12; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Drive_12")
	  double	Elevation_Surface_Temperature_Setpoint_Group_1; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Setpoint_Group_1")
	  double	Elevation_Surface_Temperature_Setpoint_Group_2; // @Metadata=(Units="deg_C",Description="Elevation_Surface_Temperature_Setpoint_Group_2")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Elevation_Drives_Thermal_dbb4b986 
struct Encoder_EIB_dda001fb {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  unsigned long	Azimuth_Actual_Encoder_Head_1; // @Metadata=(Units="deg",Description="Azimuth_Actual_Encoder_Head_1")
	  unsigned long	Azimuth_Actual_Encoder_Head_2; // @Metadata=(Units="deg",Description="Azimuth_Actual_Encoder_Head_2")
	  unsigned long	Azimuth_Actual_Encoder_Head_3; // @Metadata=(Units="deg",Description="Azimuth_Actual_Encoder_Head_3")
	  unsigned long	Azimuth_Actual_Encoder_Head_4; // @Metadata=(Units="deg",Description="Azimuth_Actual_Encoder_Head_4")
	  unsigned long	Elevation_Actual_Encoder_Head_1; // @Metadata=(Units="deg",Description="Elevation_Actual_Encoder_Head_1")
	  unsigned long	Elevation_Actual_Encoder_Head_2; // @Metadata=(Units="deg",Description="Elevation_Actual_Encoder_Head_2")
	  unsigned long	Elevation_Actual_Encoder_Head_3; // @Metadata=(Units="deg",Description="Elevation_Actual_Encoder_Head_3")
	  unsigned long	Elevation_Actual_Encoder_Head_4; // @Metadata=(Units="deg",Description="Elevation_Actual_Encoder_Head_4")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Encoder_EIB_dda001fb 
struct General_1c4e055f {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	AmbientTemperature; // @Metadata=(Units="deg_C",Description="AmbientTemperature")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist General_1c4e055f 
struct General_Purpose_Glycol_Water_1d15a4f3 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	TMA_AZ_GP_CPM_0001; // @Metadata=(Units="unitless",Description="TMA_AZ_GP_CPM_0001")
	  double	TMA_AZ_GP_CPM_0002; // @Metadata=(Units="unitless",Description="TMA_AZ_GP_CPM_0002")
	  double	TMA_PI_GP_CPM_0001; // @Metadata=(Units="unitless",Description="TMA_PI_GP_CPM_0001")
	  double	TMA_PI_GP_CPM_0002; // @Metadata=(Units="unitless",Description="TMA_PI_GP_CPM_0002")
	  double	TMA_PI_GP_CTM_0001; // @Metadata=(Units="unitless",Description="TMA_PI_GP_CTM_0001")
	  double	TMA_PI_GP_CTM_0002; // @Metadata=(Units="unitless",Description="TMA_PI_GP_CTM_0002")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist General_Purpose_Glycol_Water_1d15a4f3 
struct Locking_Pins_849ca8f9 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	LP_Status_Drive_1; // @Metadata=(Units="unitless",Description="LP_Status_Drive_1")
	  string	LP_Status_Drive_2; // @Metadata=(Units="unitless",Description="LP_Status_Drive_2")
	  double	LP_Position_Drive_1; // @Metadata=(Units="m",Description="LP_Position_Drive_1")
	  double	LP_Position_Drive_2; // @Metadata=(Units="m",Description="LP_Position_Drive_2")
	  double	LP_Current_Drive_1; // @Metadata=(Units="A",Description="LP_Current_Drive_1")
	  double	LP_Current_Drive_2; // @Metadata=(Units="A",Description="LP_Current_Drive_2")
	  double	LP_Position_Setpoint_1; // @Metadata=(Units="m",Description="LP_Position_Setpoint_1")
	  double	LP_Position_Setpoint_2; // @Metadata=(Units="m",Description="LP_Position_Setpoint_2")
	  boolean	LP_Free_Limit_1; // @Metadata=(Units="unitless",Description="LP_Free_Limit_1")
	  boolean	LP_Free_Limit_2; // @Metadata=(Units="unitless",Description="LP_Free_Limit_2")
	  boolean	LP_Lock_Limit_1; // @Metadata=(Units="unitless",Description="LP_Lock_Limit_1")
	  boolean	LP_Lock_Limit_2; // @Metadata=(Units="unitless",Description="LP_Lock_Limit_2")
	  boolean	LP_Test_Limit_1; // @Metadata=(Units="unitless",Description="LP_Test_Limit_1")
	  boolean	LP_Test_Limit_2; // @Metadata=(Units="unitless",Description="LP_Test_Limit_2")
	  boolean	Elevation_Locking_Pin_1_Retracted; // @Metadata=(Units="unitless",Description="Elevation_Locking_Pin_1_Retracted")
	  boolean	Elevation_Locking_Pin_2_Retracted; // @Metadata=(Units="unitless",Description="Elevation_Locking_Pin_2_Retracted")
	  boolean	Elevation_Locking_Pin_1_Inserted; // @Metadata=(Units="unitless",Description="Elevation_Locking_Pin_1_Inserted")
	  boolean	Elevation_Locking_Pin_2_Inserted; // @Metadata=(Units="unitless",Description="Elevation_Locking_Pin_2_Inserted")
	  boolean	Elevation_Locking_Pin_1_Test; // @Metadata=(Units="unitless",Description="Elevation_Locking_Pin_1_Test")
	  boolean	Elevation_Locking_Pin_2_Test; // @Metadata=(Units="unitless",Description="Elevation_Locking_Pin_2_Test")
	  string	LP_Interlocks; // @Metadata=(Units="unitless",Description="LP_Interlocks")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Locking_Pins_849ca8f9 
struct Main_Power_Supply_fdbfca51 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	Power_Supply_Status; // @Metadata=(Units="unitless",Description="Power_Supply_Status")
	  string	Power_Supply_Thermal_Status; // @Metadata=(Units="unitless",Description="Power_Supply_Thermal_Status")
	  double	Power_Supply_DC_Voltage; // @Metadata=(Units="volt",Description="Power_Supply_DC_Voltage")
	  double	Power_Supply_Line_Voltage; // @Metadata=(Units="volt",Description="Power_Supply_Line_Voltage")
	  double	Power_Supply_Current; // @Metadata=(Units="A",Description="Power_Supply_Current")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Main_Power_Supply_fdbfca51 
struct Main_Power_Supply_Cabinet_6009f4bc {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	Power_Supply_Surface_Temperature; // @Metadata=(Units="deg_C",Description="Power_Supply_Surface_Temperature")
	  double	Power_Supply_Internal_Temperature; // @Metadata=(Units="deg_C",Description="Power_Supply_Internal_Temperature")
	  double	Power_Supply_Setpoint_Temperature; // @Metadata=(Units="deg_C",Description="Power_Supply_Setpoint_Temperature")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Main_Power_Supply_Cabinet_6009f4bc 
struct Mirror_Cover_8f82cbf2 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	MirrorCover_Status; // @Metadata=(Units="unitless",Description="MirrorCover_Status")
	  string	MirrorCover_1_Status; // @Metadata=(Units="unitless",Description="MirrorCover_1_Status")
	  string	MirrorCover_2_Status; // @Metadata=(Units="unitless",Description="MirrorCover_2_Status")
	  string	MirrorCover_3_Status; // @Metadata=(Units="unitless",Description="MirrorCover_3_Status")
	  string	MirrorCover_4_Status; // @Metadata=(Units="unitless",Description="MirrorCover_4_Status")
	  double	MirrorCover_1_Current; // @Metadata=(Units="A",Description="MirrorCover_1_Current")
	  double	MirrorCover_2_Current; // @Metadata=(Units="A",Description="MirrorCover_2_Current")
	  double	MirrorCover_3_Current; // @Metadata=(Units="A",Description="MirrorCover_3_Current")
	  double	MirrorCover_4_Current; // @Metadata=(Units="A",Description="MirrorCover_4_Current")
	  double	MirrorCover_1_Actual_Position; // @Metadata=(Units="deg",Description="MirrorCover_1_Actual_Position")
	  double	MirrorCover_2_Actual_Position; // @Metadata=(Units="deg",Description="MirrorCover_2_Actual_Position")
	  double	MirrorCover_3_Actual_Position; // @Metadata=(Units="deg",Description="MirrorCover_3_Actual_Position")
	  double	MirrorCover_4_Actual_Position; // @Metadata=(Units="deg",Description="MirrorCover_4_Actual_Position")
	  boolean	MirrorCover_1_Deployed_Limit_Switch; // @Metadata=(Units="unitless",Description="MirrorCover_1_Deployed_Limit_Switch")
	  boolean	MirrorCover_2_Deployed_Limit_Switch; // @Metadata=(Units="unitless",Description="MirrorCover_2_Deployed_Limit_Switch")
	  boolean	MirrorCover_3_Deployed_Limit_Switch; // @Metadata=(Units="unitless",Description="MirrorCover_3_Deployed_Limit_Switch")
	  boolean	MirrorCover_4_Deployed_Limit_Switch; // @Metadata=(Units="unitless",Description="MirrorCover_4_Deployed_Limit_Switch")
	  boolean	MirrorCover_1_Retracted_Limit_Switch; // @Metadata=(Units="unitless",Description="MirrorCover_1_Retracted_Limit_Switch")
	  boolean	MirrorCover_2_Retracted_Limit_Switch; // @Metadata=(Units="unitless",Description="MirrorCover_2_Retracted_Limit_Switch")
	  boolean	MirrorCover_3_Retracted_Limit_Switch; // @Metadata=(Units="unitless",Description="MirrorCover_3_Retracted_Limit_Switch")
	  boolean	MirrorCover_4_Retracted_Limit_Switch; // @Metadata=(Units="unitless",Description="MirrorCover_4_Retracted_Limit_Switch")
	  string	MirrorCover_Interlocks; // @Metadata=(Units="unitless",Description="MirrorCover_Interlocks")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Mirror_Cover_8f82cbf2 
struct Mirror_Cover_Locks_dd5e8f37 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	MirrorCoverLock_1_Status; // @Metadata=(Units="unitless",Description="MirrorCoverLock_1_Status")
	  string	MirrorCoverLock_2_Status; // @Metadata=(Units="unitless",Description="MirrorCoverLock_2_Status")
	  string	MirrorCoverLock_3_Status; // @Metadata=(Units="unitless",Description="MirrorCoverLock_3_Status")
	  string	MirrorCoverLock_4_Status; // @Metadata=(Units="unitless",Description="MirrorCoverLock_4_Status")
	  double	MirrorCoverLock_1_Actual_Position; // @Metadata=(Units="deg",Description="MirrorCoverLock_1_Actual_Position")
	  double	MirrorCoverLock_2_Actual_Position; // @Metadata=(Units="deg",Description="MirrorCoverLock_2_Actual_Position")
	  double	MirrorCoverLock_3_Actual_Position; // @Metadata=(Units="deg",Description="MirrorCoverLock_3_Actual_Position")
	  double	MirrorCoverLock_4_Actual_Position; // @Metadata=(Units="deg",Description="MirrorCoverLock_4_Actual_Position")
	  double	MirrorCoverLock_1_Current; // @Metadata=(Units="A",Description="MirrorCoverLock_1_Current")
	  double	MirrorCoverLock_2_Current; // @Metadata=(Units="A",Description="MirrorCoverLock_2_Current")
	  double	MirrorCoverLock_3_Current; // @Metadata=(Units="A",Description="MirrorCoverLock_3_Current")
	  double	MirrorCoverLock_4_Current; // @Metadata=(Units="A",Description="MirrorCoverLock_4_Current")
	  boolean	MirrorCoverLock_3_Unlocked_Limit_Switch; // @Metadata=(Units="unitless",Description="MirrorCoverLock_3_Unlocked_Limit_Switch")
	  boolean	MirrorCoverLock_2_Unlocked_Limit_Switch; // @Metadata=(Units="unitless",Description="MirrorCoverLock_2_Unlocked_Limit_Switch")
	  boolean	MirrorCoverLock_1_Unlocked_Limit_Switch; // @Metadata=(Units="unitless",Description="MirrorCoverLock_1_Unlocked_Limit_Switch")
	  boolean	MirrorCoverLock_4_Unlocked_Limit_Switch; // @Metadata=(Units="unitless",Description="MirrorCoverLock_4_Unlocked_Limit_Switch")
	  boolean	MirrorCoverLock_3_Locked_Limit_Switch; // @Metadata=(Units="unitless",Description="MirrorCoverLock_3_Locked_Limit_Switch")
	  boolean	MirrorCoverLock_2_Locked_Limit_Switch; // @Metadata=(Units="unitless",Description="MirrorCoverLock_2_Locked_Limit_Switch")
	  boolean	MirrorCoverLock_1_Locked_Limit_Switch; // @Metadata=(Units="unitless",Description="MirrorCoverLock_1_Locked_Limit_Switch")
	  boolean	MirrorCoverLock_4_Locked_Limit_Switch; // @Metadata=(Units="unitless",Description="MirrorCoverLock_4_Locked_Limit_Switch")
	  string	MirrorCoverLock_Interlocks; // @Metadata=(Units="unitless",Description="MirrorCoverLock_Interlocks")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Mirror_Cover_Locks_dd5e8f37 
struct Mount_Control_Main_Cabinet_a8c405f7 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	Main_Cabinet_Status; // @Metadata=(Units="unitless",Description="Main_Cabinet_Status")
	  double	Main_Cabinet_External_Temperature; // @Metadata=(Units="deg_C",Description="Main_Cabinet_External_Temperature")
	  double	Main_Cabinet_Internal_Temperature_1; // @Metadata=(Units="deg_C",Description="Main_Cabinet_Internal_Temperature_1")
	  double	Main_Cabinet_Internal_Temperature_2; // @Metadata=(Units="deg_C",Description="Main_Cabinet_Internal_Temperature_2")
	  double	Main_Cabinet_Setpoint_Temperature; // @Metadata=(Units="deg_C",Description="Main_Cabinet_Setpoint_Temperature")
	  boolean	Main_Cabinet_Doors_Open; // @Metadata=(Units="unitless",Description="Main_Cabinet_Doors_Open")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Mount_Control_Main_Cabinet_a8c405f7 
struct OSS_ca760027 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	OSS_Status; // @Metadata=(Units="unitless",Description="OSS_Status")
	  string	OSS_A_Status_valve_5802; // @Metadata=(Units="unitless",Description="OSS_A_Status_valve_5802")
	  string	OSS_A_Status_valve_5801; // @Metadata=(Units="unitless",Description="OSS_A_Status_valve_5801")
	  string	OSS_A_Status_valve_5303; // @Metadata=(Units="unitless",Description="OSS_A_Status_valve_5303")
	  string	OSS_A_Status_valve_5302; // @Metadata=(Units="unitless",Description="OSS_A_Status_valve_5302")
	  string	OSS_A_Status_valve_5301; // @Metadata=(Units="unitless",Description="OSS_A_Status_valve_5301")
	  string	OSS_A_Status_valve_5011; // @Metadata=(Units="unitless",Description="OSS_A_Status_valve_5011")
	  string	OSS_A_Status_pump_5004; // @Metadata=(Units="unitless",Description="OSS_A_Status_pump_5004")
	  string	OSS_A_Status_Filter_7; // @Metadata=(Units="unitless",Description="OSS_A_Status_Filter_7")
	  string	Status_Bottom_centre_pump_5012; // @Metadata=(Units="unitless",Description="Status_Bottom_centre_pump_5012")
	  string	Status_Bottom_centre_valve_5001; // @Metadata=(Units="unitless",Description="Status_Bottom_centre_valve_5001")
	  string	Status_Bottom_heater_HET_5001; // @Metadata=(Units="unitless",Description="Status_Bottom_heater_HET_5001")
	  string	Status_Bottom_left_pump_5011; // @Metadata=(Units="unitless",Description="Status_Bottom_left_pump_5011")
	  string	Status_Bottom_left_valve_5000; // @Metadata=(Units="unitless",Description="Status_Bottom_left_valve_5000")
	  string	Status_Bottom_right_pump_5013; // @Metadata=(Units="unitless",Description="Status_Bottom_right_pump_5013")
	  string	Status_Bottom_right_valve_5002; // @Metadata=(Units="unitless",Description="Status_Bottom_right_valve_5002")
	  string	Status_bridge_pump_running_unit_1; // @Metadata=(Units="unitless",Description="Status_bridge_pump_running_unit_1")
	  string	Status_bridge_pump_running_unit_2; // @Metadata=(Units="unitless",Description="Status_bridge_pump_running_unit_2")
	  string	Status_cooler_running_unit_1; // @Metadata=(Units="unitless",Description="Status_cooler_running_unit_1")
	  string	Status_cooler_running_unit_2; // @Metadata=(Units="unitless",Description="Status_cooler_running_unit_2")
	  string	Status_Filter_5; // @Metadata=(Units="unitless",Description="Status_Filter_5")
	  string	Status_Filter_6; // @Metadata=(Units="unitless",Description="Status_Filter_6")
	  string	Status_pump_5001; // @Metadata=(Units="unitless",Description="Status_pump_5001")
	  string	Status_valve_5201; // @Metadata=(Units="unitless",Description="Status_valve_5201")
	  string	OSS_MP_Status_centre_valve_5009; // @Metadata=(Units="unitless",Description="OSS_MP_Status_centre_valve_5009")
	  string	OSS_MP_Status_Filter_1; // @Metadata=(Units="unitless",Description="OSS_MP_Status_Filter_1")
	  string	OSS_MP_Status_Filter_2; // @Metadata=(Units="unitless",Description="OSS_MP_Status_Filter_2")
	  string	OSS_MP_Status_Filter_3; // @Metadata=(Units="unitless",Description="OSS_MP_Status_Filter_3")
	  string	OSS_MP_Status_Filter_4; // @Metadata=(Units="unitless",Description="OSS_MP_Status_Filter_4")
	  string	OSS_MP_Status_left_valve_5008; // @Metadata=(Units="unitless",Description="OSS_MP_Status_left_valve_5008")
	  string	OSS_MP_Status_pump_5001; // @Metadata=(Units="unitless",Description="OSS_MP_Status_pump_5001")
	  string	OSS_MP_Status_pump_5002; // @Metadata=(Units="unitless",Description="OSS_MP_Status_pump_5002")
	  string	OSS_MP_Status_pump_5003; // @Metadata=(Units="unitless",Description="OSS_MP_Status_pump_5003")
	  string	OSS_MP_Status_right_valve_5010; // @Metadata=(Units="unitless",Description="OSS_MP_Status_right_valve_5010")
	  double	OSS_A_CPM_5007; // @Metadata=(Units="unitless",Description="OSS_A_CPM_5007")
	  double	OSS_A_CPM_5008; // @Metadata=(Units="unitless",Description="OSS_A_CPM_5008")
	  double	OSS_A_CPM_5021; // @Metadata=(Units="unitless",Description="OSS_A_CPM_5021")
	  double	OSS_A_CPM_5031; // @Metadata=(Units="unitless",Description="OSS_A_CPM_5031")
	  double	OSS_A_CPM_5053; // @Metadata=(Units="unitless",Description="OSS_A_CPM_5053")
	  double	Temperature_Oil_from_bearings_XPos_side; // @Metadata=(Units="deg_C",Description="Temperature_Oil_from_bearings_XPos_side")
	  double	Temperature_Oil_from_bearings_XNeg_side; // @Metadata=(Units="deg_C",Description="Temperature_Oil_from_bearings_XNeg_side")
	  double	Temperature_Tank; // @Metadata=(Units="deg_C",Description="Temperature_Tank")
	  double	Pressure_Tank; // @Metadata=(Units="bar",Description="Pressure_Tank")
	  double	Ambient_Temperature_Measured_by_OSS; // @Metadata=(Units="deg_C",Description="Ambient_Temperature_Measured_by_OSS")
	  double	OSS_Oil_Valve_feedback; // @Metadata=(Units="unitless",Description="OSS_Oil_Valve_feedback")
	  double	OSS_Oil_Cooling_Valve_control_signal; // @Metadata=(Units="unitless",Description="OSS_Oil_Cooling_Valve_control_signal")
	  double	OSS_Oil_Cooling_CTM_5013; // @Metadata=(Units="unitless",Description="OSS_Oil_Cooling_CTM_5013")
	  double	OSS_Oil_Cooling_CTM_5012; // @Metadata=(Units="unitless",Description="OSS_Oil_Cooling_CTM_5012")
	  double	OSS_Oil_Cooling_CPM_5052; // @Metadata=(Units="unitless",Description="OSS_Oil_Cooling_CPM_5052")
	  double	OSS_Oil_Cooling_CPM_5051; // @Metadata=(Units="unitless",Description="OSS_Oil_Cooling_CPM_5051")
	  double	OSS_MP_CTM_5002; // @Metadata=(Units="unitless",Description="OSS_MP_CTM_5002")
	};
#pragma keylist OSS_ca760027 
struct OSS2_f5b1569e {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	OSS_MP_CTM_5001; // @Metadata=(Units="unitless",Description="OSS_MP_CTM_5001")
	  double	OSS_MP_CPM_5057; // @Metadata=(Units="unitless",Description="OSS_MP_CPM_5057")
	  double	OSS_MP_CPM_5056; // @Metadata=(Units="unitless",Description="OSS_MP_CPM_5056")
	  double	OSS_MP_CPM_5055; // @Metadata=(Units="unitless",Description="OSS_MP_CPM_5055")
	  double	OSS_MP_CPM_5054; // @Metadata=(Units="unitless",Description="OSS_MP_CPM_5054")
	  double	OSS_MP_CPM_5013; // @Metadata=(Units="unitless",Description="OSS_MP_CPM_5013")
	  double	OSS_MP_CPM_5012; // @Metadata=(Units="unitless",Description="OSS_MP_CPM_5012")
	  double	OSS_MP_CPM_5011; // @Metadata=(Units="unitless",Description="OSS_MP_CPM_5011")
	  double	OSS_MP_CPM_5006; // @Metadata=(Units="unitless",Description="OSS_MP_CPM_5006")
	  double	OSS_MP_CPM_5005; // @Metadata=(Units="unitless",Description="OSS_MP_CPM_5005")
	  double	OSS_MP_CPM_5004; // @Metadata=(Units="unitless",Description="OSS_MP_CPM_5004")
	  double	OSS_MP_CPM_5003; // @Metadata=(Units="unitless",Description="OSS_MP_CPM_5003")
	  double	OSS_MP_CPM_5002; // @Metadata=(Units="unitless",Description="OSS_MP_CPM_5002")
	  double	OSS_MP_CPM_5001; // @Metadata=(Units="unitless",Description="OSS_MP_CPM_5001")
	  double	AZ_XPos_M1_left_Bearing_1; // @Metadata=(Units="unitless",Description="AZ_XPos_M1_left_Bearing_1")
	  double	AZ_XPos_M1_left_Bearing_2; // @Metadata=(Units="unitless",Description="AZ_XPos_M1_left_Bearing_2")
	  double	AZ_XPos_M1_left_Bearing_3; // @Metadata=(Units="unitless",Description="AZ_XPos_M1_left_Bearing_3")
	  double	AZ_XPos_M1_left_Bearing_calculated; // @Metadata=(Units="unitless",Description="AZ_XPos_M1_left_Bearing_calculated")
	  double	AZ_XPos_M1_right_Bearing_1; // @Metadata=(Units="unitless",Description="AZ_XPos_M1_right_Bearing_1")
	  double	AZ_XPos_M1_right_Bearing_2; // @Metadata=(Units="unitless",Description="AZ_XPos_M1_right_Bearing_2")
	  double	AZ_XPos_M1_right_Bearing_3; // @Metadata=(Units="unitless",Description="AZ_XPos_M1_right_Bearing_3")
	  double	AZ_XPos_M1_right_Bearing_calculated; // @Metadata=(Units="unitless",Description="AZ_XPos_M1_right_Bearing_calculated")
	  double	AZ_XPos_M2_left_Bearing_1; // @Metadata=(Units="unitless",Description="AZ_XPos_M2_left_Bearing_1")
	  double	AZ_XPos_M2_left_Bearing_2; // @Metadata=(Units="unitless",Description="AZ_XPos_M2_left_Bearing_2")
	  double	AZ_XPos_M2_left_Bearing_3; // @Metadata=(Units="unitless",Description="AZ_XPos_M2_left_Bearing_3")
	  double	AZ_XPos_M2_left_Bearing_calculated; // @Metadata=(Units="unitless",Description="AZ_XPos_M2_left_Bearing_calculated")
	  double	AZ_XPos_M2_right_Bearing_1; // @Metadata=(Units="unitless",Description="AZ_XPos_M2_right_Bearing_1")
	  double	AZ_XPos_M2_right_Bearing_2; // @Metadata=(Units="unitless",Description="AZ_XPos_M2_right_Bearing_2")
	  double	AZ_XPos_M2_right_Bearing_3; // @Metadata=(Units="unitless",Description="AZ_XPos_M2_right_Bearing_3")
	  double	AZ_XPos_M2_right_Bearing_calculated; // @Metadata=(Units="unitless",Description="AZ_XPos_M2_right_Bearing_calculated")
	  double	AZ_XNeg_M1_left_Bearing_1; // @Metadata=(Units="unitless",Description="AZ_XNeg_M1_left_Bearing_1")
	  double	AZ_XNeg_M1_left_Bearing_2; // @Metadata=(Units="unitless",Description="AZ_XNeg_M1_left_Bearing_2")
	  double	AZ_XNeg_M1_left_Bearing_3; // @Metadata=(Units="unitless",Description="AZ_XNeg_M1_left_Bearing_3")
	  double	AZ_XNeg_M1_left_Bearing_calculated; // @Metadata=(Units="unitless",Description="AZ_XNeg_M1_left_Bearing_calculated")
	  double	AZ_XNeg_M1_right_Bearing_1; // @Metadata=(Units="unitless",Description="AZ_XNeg_M1_right_Bearing_1")
	  double	AZ_XNeg_M1_right_Bearing_2; // @Metadata=(Units="unitless",Description="AZ_XNeg_M1_right_Bearing_2")
	  double	AZ_XNeg_M1_right_Bearing_3; // @Metadata=(Units="unitless",Description="AZ_XNeg_M1_right_Bearing_3")
	  double	AZ_XNeg_M1_right_Bearing_calculated; // @Metadata=(Units="unitless",Description="AZ_XNeg_M1_right_Bearing_calculated")
	  double	AZ_XNeg_M2_left_Bearing_1; // @Metadata=(Units="unitless",Description="AZ_XNeg_M2_left_Bearing_1")
	  double	AZ_XNeg_M2_left_Bearing_2; // @Metadata=(Units="unitless",Description="AZ_XNeg_M2_left_Bearing_2")
	  double	AZ_XNeg_M2_left_Bearing_3; // @Metadata=(Units="unitless",Description="AZ_XNeg_M2_left_Bearing_3")
	  double	AZ_XNeg_M2_left_Bearing_calculated; // @Metadata=(Units="unitless",Description="AZ_XNeg_M2_left_Bearing_calculated")
	  double	AZ_XNeg_M2_right_Bearing_1; // @Metadata=(Units="unitless",Description="AZ_XNeg_M2_right_Bearing_1")
	  double	AZ_XNeg_M2_right_Bearing_2; // @Metadata=(Units="unitless",Description="AZ_XNeg_M2_right_Bearing_2")
	  double	AZ_XNeg_M2_right_Bearing_3; // @Metadata=(Units="unitless",Description="AZ_XNeg_M2_right_Bearing_3")
	  double	AZ_XNeg_M2_right_Bearing_calculated; // @Metadata=(Units="unitless",Description="AZ_XNeg_M2_right_Bearing_calculated")
	};
#pragma keylist OSS2_f5b1569e 
struct OSS4_8b6a68b3 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	CFM_5001; // @Metadata=(Units="unitless",Description="CFM_5001")
	  double	CFM_5002; // @Metadata=(Units="unitless",Description="CFM_5002")
	  double	CFM_5021; // @Metadata=(Units="unitless",Description="CFM_5021")
	  double	CFM_5022; // @Metadata=(Units="unitless",Description="CFM_5022")
	  double	CFM_5031; // @Metadata=(Units="unitless",Description="CFM_5031")
	  double	CFM_5032; // @Metadata=(Units="unitless",Description="CFM_5032")
	  double	CFM_5051; // @Metadata=(Units="unitless",Description="CFM_5051")
	  double	CFM_5052; // @Metadata=(Units="unitless",Description="CFM_5052")
	  double	CPM_5001; // @Metadata=(Units="unitless",Description="CPM_5001")
	  double	CPM_5002; // @Metadata=(Units="unitless",Description="CPM_5002")
	  double	CPM_5003; // @Metadata=(Units="unitless",Description="CPM_5003")
	  double	CPM_5021; // @Metadata=(Units="unitless",Description="CPM_5021")
	  double	CPM_5022; // @Metadata=(Units="unitless",Description="CPM_5022")
	  double	CPM_5023; // @Metadata=(Units="unitless",Description="CPM_5023")
	  double	CPM_5031; // @Metadata=(Units="unitless",Description="CPM_5031")
	  double	CPM_5032; // @Metadata=(Units="unitless",Description="CPM_5032")
	  double	CPM_5033; // @Metadata=(Units="unitless",Description="CPM_5033")
	  double	CPM_5034; // @Metadata=(Units="unitless",Description="CPM_5034")
	  double	CPM_5051; // @Metadata=(Units="unitless",Description="CPM_5051")
	  double	CPM_5052; // @Metadata=(Units="unitless",Description="CPM_5052")
	  double	CPM_5053; // @Metadata=(Units="unitless",Description="CPM_5053")
	  double	CPM_5054; // @Metadata=(Units="unitless",Description="CPM_5054")
	  double	CTM_5001; // @Metadata=(Units="unitless",Description="CTM_5001")
	  double	CTM_5021; // @Metadata=(Units="unitless",Description="CTM_5021")
	  double	CTM_5031; // @Metadata=(Units="unitless",Description="CTM_5031")
	  double	CTM_5051; // @Metadata=(Units="unitless",Description="CTM_5051")
	  double	AZ_XPos_M3_left_Bearing_1; // @Metadata=(Units="unitless",Description="AZ_XPos_M3_left_Bearing_1")
	  double	AZ_XPos_M3_left_Bearing_2; // @Metadata=(Units="unitless",Description="AZ_XPos_M3_left_Bearing_2")
	  double	AZ_XPos_M3_left_Bearing_3; // @Metadata=(Units="unitless",Description="AZ_XPos_M3_left_Bearing_3")
	  double	AZ_XPos_M3_left_Bearing_calculated; // @Metadata=(Units="unitless",Description="AZ_XPos_M3_left_Bearing_calculated")
	  double	AZ_XPos_M3_middle_Bearing_1; // @Metadata=(Units="unitless",Description="AZ_XPos_M3_middle_Bearing_1")
	  double	AZ_XPos_M3_middle_Bearing_2; // @Metadata=(Units="unitless",Description="AZ_XPos_M3_middle_Bearing_2")
	  double	AZ_XPos_M3_middle_Bearing_3; // @Metadata=(Units="unitless",Description="AZ_XPos_M3_middle_Bearing_3")
	  double	AZ_XPos_M3_middle_Bearing_calculated; // @Metadata=(Units="unitless",Description="AZ_XPos_M3_middle_Bearing_calculated")
	  double	AZ_XPos_M3_right_Bearing_1; // @Metadata=(Units="unitless",Description="AZ_XPos_M3_right_Bearing_1")
	  double	AZ_XPos_M3_right_Bearing_2; // @Metadata=(Units="unitless",Description="AZ_XPos_M3_right_Bearing_2")
	  double	AZ_XPos_M3_right_Bearing_3; // @Metadata=(Units="unitless",Description="AZ_XPos_M3_right_Bearing_3")
	  double	AZ_XPos_M3_right_Bearing_calculated; // @Metadata=(Units="unitless",Description="AZ_XPos_M3_right_Bearing_calculated")
	  double	AZ_XNeg_M3_left_Bearing_1; // @Metadata=(Units="unitless",Description="AZ_XNeg_M3_left_Bearing_1")
	  double	AZ_XNeg_M3_left_Bearing_2; // @Metadata=(Units="unitless",Description="AZ_XNeg_M3_left_Bearing_2")
	  double	AZ_XNeg_M3_left_Bearing_3; // @Metadata=(Units="unitless",Description="AZ_XNeg_M3_left_Bearing_3")
	  double	AZ_XNeg_M3_left_Bearing_calculated; // @Metadata=(Units="unitless",Description="AZ_XNeg_M3_left_Bearing_calculated")
	  double	AZ_XNeg_M3_middle_Bearing_1; // @Metadata=(Units="unitless",Description="AZ_XNeg_M3_middle_Bearing_1")
	  double	AZ_XNeg_M3_middle_Bearing_2; // @Metadata=(Units="unitless",Description="AZ_XNeg_M3_middle_Bearing_2")
	  double	AZ_XNeg_M3_middle_Bearing_3; // @Metadata=(Units="unitless",Description="AZ_XNeg_M3_middle_Bearing_3")
	  double	AZ_XNeg_M3_middle_Bearing_calculated; // @Metadata=(Units="unitless",Description="AZ_XNeg_M3_middle_Bearing_calculated")
	  double	AZ_XNeg_M3_right_Bearing_1; // @Metadata=(Units="unitless",Description="AZ_XNeg_M3_right_Bearing_1")
	  double	AZ_XNeg_M3_right_Bearing_2; // @Metadata=(Units="unitless",Description="AZ_XNeg_M3_right_Bearing_2")
	  double	AZ_XNeg_M3_right_Bearing_3; // @Metadata=(Units="unitless",Description="AZ_XNeg_M3_right_Bearing_3")
	  double	AZ_XNeg_M3_right_Bearing_calculated; // @Metadata=(Units="unitless",Description="AZ_XNeg_M3_right_Bearing_calculated")
	};
#pragma keylist OSS4_8b6a68b3 
struct OSS5_f6b212e4 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	CFM_5011; // @Metadata=(Units="unitless",Description="CFM_5011")
	  double	CFM_5012; // @Metadata=(Units="unitless",Description="CFM_5012")
	  double	CFM_5013; // @Metadata=(Units="unitless",Description="CFM_5013")
	  double	CFM_5041; // @Metadata=(Units="unitless",Description="CFM_5041")
	  double	CFM_5042; // @Metadata=(Units="unitless",Description="CFM_5042")
	  double	CFM_5043; // @Metadata=(Units="unitless",Description="CFM_5043")
	  double	CPM_5011; // @Metadata=(Units="unitless",Description="CPM_5011")
	  double	CPM_5012; // @Metadata=(Units="unitless",Description="CPM_5012")
	  double	CPM_5013; // @Metadata=(Units="unitless",Description="CPM_5013")
	  double	CPM_5014; // @Metadata=(Units="unitless",Description="CPM_5014")
	  double	CPM_5015; // @Metadata=(Units="unitless",Description="CPM_5015")
	  double	CPM_5016; // @Metadata=(Units="unitless",Description="CPM_5016")
	  double	CPM_5041; // @Metadata=(Units="unitless",Description="CPM_5041")
	  double	CPM_5042; // @Metadata=(Units="unitless",Description="CPM_5042")
	  double	CPM_5043; // @Metadata=(Units="unitless",Description="CPM_5043")
	  double	CPM_5044; // @Metadata=(Units="unitless",Description="CPM_5044")
	  double	CPM_5045; // @Metadata=(Units="unitless",Description="CPM_5045")
	  double	CPM_5046; // @Metadata=(Units="unitless",Description="CPM_5046")
	  double	CTM_5011; // @Metadata=(Units="unitless",Description="CTM_5011")
	  double	CTM_5041; // @Metadata=(Units="unitless",Description="CTM_5041")
	  double	EL_XPos_M1_left_Bearing_1; // @Metadata=(Units="unitless",Description="EL_XPos_M1_left_Bearing_1")
	  double	EL_XPos_M1_left_Bearing_2; // @Metadata=(Units="unitless",Description="EL_XPos_M1_left_Bearing_2")
	  double	EL_XPos_M1_left_Bearing_3; // @Metadata=(Units="unitless",Description="EL_XPos_M1_left_Bearing_3")
	  double	EL_XPos_M1_left_Bearing_calculated; // @Metadata=(Units="unitless",Description="EL_XPos_M1_left_Bearing_calculated")
	  double	EL_XPos_M1_right_Bearing_1; // @Metadata=(Units="unitless",Description="EL_XPos_M1_right_Bearing_1")
	  double	EL_XPos_M1_right_Bearing_2; // @Metadata=(Units="unitless",Description="EL_XPos_M1_right_Bearing_2")
	  double	EL_XPos_M1_right_Bearing_3; // @Metadata=(Units="unitless",Description="EL_XPos_M1_right_Bearing_3")
	  double	EL_XPos_M1_right_Bearing_calculated; // @Metadata=(Units="unitless",Description="EL_XPos_M1_right_Bearing_calculated")
	  double	EL_XPos_M2_left_Bearing_1; // @Metadata=(Units="unitless",Description="EL_XPos_M2_left_Bearing_1")
	  double	EL_XPos_M2_left_Bearing_2; // @Metadata=(Units="unitless",Description="EL_XPos_M2_left_Bearing_2")
	  double	EL_XPos_M2_left_Bearing_3; // @Metadata=(Units="unitless",Description="EL_XPos_M2_left_Bearing_3")
	  double	EL_XPos_M2_left_Bearing_calculated; // @Metadata=(Units="unitless",Description="EL_XPos_M2_left_Bearing_calculated")
	  double	EL_XPos_M2_right_Bearing_1; // @Metadata=(Units="unitless",Description="EL_XPos_M2_right_Bearing_1")
	  double	EL_XPos_M2_right_Bearing_2; // @Metadata=(Units="unitless",Description="EL_XPos_M2_right_Bearing_2")
	  double	EL_XPos_M2_right_Bearing_3; // @Metadata=(Units="unitless",Description="EL_XPos_M2_right_Bearing_3")
	  double	El_XPos_M2_right_Bearing_calculated; // @Metadata=(Units="unitless",Description="El_XPos_M2_right_Bearing_calculated")
	  double	EL_XNeg_M1_left_Bearing_1; // @Metadata=(Units="unitless",Description="EL_XNeg_M1_left_Bearing_1")
	  double	EL_XNeg_M1_left_Bearing_2; // @Metadata=(Units="unitless",Description="EL_XNeg_M1_left_Bearing_2")
	  double	EL_XNeg_M1_left_Bearing_3; // @Metadata=(Units="unitless",Description="EL_XNeg_M1_left_Bearing_3")
	  double	EL_XNeg_M1_left_Bearing_calculated; // @Metadata=(Units="unitless",Description="EL_XNeg_M1_left_Bearing_calculated")
	  double	EL_XNeg_M1_right_Bearing_1; // @Metadata=(Units="unitless",Description="EL_XNeg_M1_right_Bearing_1")
	  double	EL_XNeg_M1_right_Bearing_2; // @Metadata=(Units="unitless",Description="EL_XNeg_M1_right_Bearing_2")
	  double	EL_XNeg_M1_right_Bearing_3; // @Metadata=(Units="unitless",Description="EL_XNeg_M1_right_Bearing_3")
	  double	EL_XNeg_M1_right_Bearing_calculated; // @Metadata=(Units="unitless",Description="EL_XNeg_M1_right_Bearing_calculated")
	  double	EL_XNeg_M2_left_Bearing_1; // @Metadata=(Units="unitless",Description="EL_XNeg_M2_left_Bearing_1")
	  double	EL_XNeg_M2_left_Bearing_2; // @Metadata=(Units="unitless",Description="EL_XNeg_M2_left_Bearing_2")
	  double	EL_XNeg_M2_left_Bearing_3; // @Metadata=(Units="unitless",Description="EL_XNeg_M2_left_Bearing_3")
	  double	EL_XNeg_M2_left_Bearing_calculated; // @Metadata=(Units="unitless",Description="EL_XNeg_M2_left_Bearing_calculated")
	  double	EL_XNeg_M2_right_Bearing_1; // @Metadata=(Units="unitless",Description="EL_XNeg_M2_right_Bearing_1")
	  double	EL_XNeg_M2_right_Bearing_2; // @Metadata=(Units="unitless",Description="EL_XNeg_M2_right_Bearing_2")
	  double	EL_XNeg_M2_right_Bearing_3; // @Metadata=(Units="unitless",Description="EL_XNeg_M2_right_Bearing_3")
	  double	El_XNeg_M2_right_Bearing_calculated; // @Metadata=(Units="unitless",Description="El_XNeg_M2_right_Bearing_calculated")
	};
#pragma keylist OSS5_f6b212e4 
struct OSS6_0fcb2186 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	EL_CFM_5001; // @Metadata=(Units="unitless",Description="EL_CFM_5001")
	  double	EL_CFM_5002; // @Metadata=(Units="unitless",Description="EL_CFM_5002")
	  double	EL_CFM_5011; // @Metadata=(Units="unitless",Description="EL_CFM_5011")
	  double	EL_CFM_5012; // @Metadata=(Units="unitless",Description="EL_CFM_5012")
	  double	EL_CFM_5021; // @Metadata=(Units="unitless",Description="EL_CFM_5021")
	  double	EL_CFM_5022; // @Metadata=(Units="unitless",Description="EL_CFM_5022")
	  double	EL_CFM_5031; // @Metadata=(Units="unitless",Description="EL_CFM_5031")
	  double	EL_CFM_5032; // @Metadata=(Units="unitless",Description="EL_CFM_5032")
	  double	EL_CPM_5001; // @Metadata=(Units="unitless",Description="EL_CPM_5001")
	  double	EL_CPM_5002; // @Metadata=(Units="unitless",Description="EL_CPM_5002")
	  double	EL_CPM_5003; // @Metadata=(Units="unitless",Description="EL_CPM_5003")
	  double	EL_CPM_5011; // @Metadata=(Units="unitless",Description="EL_CPM_5011")
	  double	EL_CPM_5012; // @Metadata=(Units="unitless",Description="EL_CPM_5012")
	  double	EL_CPM_5013; // @Metadata=(Units="unitless",Description="EL_CPM_5013")
	  double	EL_CPM_5021; // @Metadata=(Units="unitless",Description="EL_CPM_5021")
	  double	EL_CPM_5022; // @Metadata=(Units="unitless",Description="EL_CPM_5022")
	  double	EL_CPM_5023; // @Metadata=(Units="unitless",Description="EL_CPM_5023")
	  double	EL_CPM_5024; // @Metadata=(Units="unitless",Description="EL_CPM_5024")
	  double	EL_CPM_5031; // @Metadata=(Units="unitless",Description="EL_CPM_5031")
	  double	EL_CPM_5032; // @Metadata=(Units="unitless",Description="EL_CPM_5032")
	  double	EL_CPM_5033; // @Metadata=(Units="unitless",Description="EL_CPM_5033")
	  double	EL_CTM_5001; // @Metadata=(Units="unitless",Description="EL_CTM_5001")
	  double	EL_CTM_5011; // @Metadata=(Units="unitless",Description="EL_CTM_5011")
	  double	EL_CTM_5021; // @Metadata=(Units="unitless",Description="EL_CTM_5021")
	  double	EL_CTM_5031; // @Metadata=(Units="unitless",Description="EL_CTM_5031")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist OSS6_0fcb2186 
struct Safety_System_dabc781b {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	AZ_LimPos_AND_topple_block_pos_A; // @Metadata=(Units="unitless",Description="AZ_LimPos_AND_topple_block_pos_A")
	  boolean	AZ_LimNeg_AND_topple_block_pos_B; // @Metadata=(Units="unitless",Description="AZ_LimNeg_AND_topple_block_pos_B")
	  boolean	AZ_Overspeed; // @Metadata=(Units="unitless",Description="AZ_Overspeed")
	  boolean	AZ_press_brake; // @Metadata=(Units="unitless",Description="AZ_press_brake")
	  boolean	AZ_brake_NO_actuated; // @Metadata=(Units="unitless",Description="AZ_brake_NO_actuated")
	  boolean	EL_LimPos; // @Metadata=(Units="unitless",Description="EL_LimPos")
	  boolean	EL_LimNeg; // @Metadata=(Units="unitless",Description="EL_LimNeg")
	  boolean	EL_Overspeed; // @Metadata=(Units="unitless",Description="EL_Overspeed")
	  boolean	EL_press_brake; // @Metadata=(Units="unitless",Description="EL_press_brake")
	  boolean	EL_brake_NO_actuated; // @Metadata=(Units="unitless",Description="EL_brake_NO_actuated")
	  boolean	Mirror_cover_position_NO_Closed; // @Metadata=(Units="unitless",Description="Mirror_cover_position_NO_Closed")
	  boolean	Mirror_cover_locked_switch; // @Metadata=(Units="unitless",Description="Mirror_cover_locked_switch")
	  boolean	AZ_cable_wrap_LimPos; // @Metadata=(Units="unitless",Description="AZ_cable_wrap_LimPos")
	  boolean	AZ_cable_wrap_LimNeg; // @Metadata=(Units="unitless",Description="AZ_cable_wrap_LimNeg")
	  boolean	El_locking_pin_inserted; // @Metadata=(Units="unitless",Description="El_locking_pin_inserted")
	  boolean	El_locking_pin_test_position; // @Metadata=(Units="unitless",Description="El_locking_pin_test_position")
	  boolean	El_locking_retracted; // @Metadata=(Units="unitless",Description="El_locking_retracted")
	  boolean	Access_door_NO_closed; // @Metadata=(Units="unitless",Description="Access_door_NO_closed")
	  boolean	Access_door_ladder_NO_parked; // @Metadata=(Units="unitless",Description="Access_door_ladder_NO_parked")
	  boolean	Hatch_NO_Closed; // @Metadata=(Units="unitless",Description="Hatch_NO_Closed")
	  boolean	Platform_NO_parking; // @Metadata=(Units="unitless",Description="Platform_NO_parking")
	  boolean	Platform_NO_total_extended; // @Metadata=(Units="unitless",Description="Platform_NO_total_extended")
	  boolean	Platform_extension_NO_inserted; // @Metadata=(Units="unitless",Description="Platform_extension_NO_inserted")
	  boolean	Pull_CordPos; // @Metadata=(Units="unitless",Description="Pull_CordPos")
	  boolean	Pull_CordNeg; // @Metadata=(Units="unitless",Description="Pull_CordNeg")
	  boolean	ETPB; // @Metadata=(Units="unitless",Description="ETPB")
	  boolean	ETPB_Phase; // @Metadata=(Units="unitless",Description="ETPB_Phase")
	  boolean	Global_IS_Interlock; // @Metadata=(Units="unitless",Description="Global_IS_Interlock")
	  boolean	Earthquake; // @Metadata=(Units="unitless",Description="Earthquake")
	  boolean	SKF_NO_ok; // @Metadata=(Units="unitless",Description="SKF_NO_ok")
	  boolean	Phase_NO_ok; // @Metadata=(Units="unitless",Description="Phase_NO_ok")
	  boolean	MCS_watchdog; // @Metadata=(Units="unitless",Description="MCS_watchdog")
	  boolean	Loss_communication; // @Metadata=(Units="unitless",Description="Loss_communication")
	  boolean	GISfailure; // @Metadata=(Units="unitless",Description="GISfailure")
	  boolean	PierAccess; // @Metadata=(Units="unitless",Description="PierAccess")
	  boolean	DomeAccess; // @Metadata=(Units="unitless",Description="DomeAccess")
	  boolean	ETPBdome; // @Metadata=(Units="unitless",Description="ETPBdome")
	  boolean	DomeParked; // @Metadata=(Units="unitless",Description="DomeParked")
	  boolean	M1M3Interlok; // @Metadata=(Units="unitless",Description="M1M3Interlok")
	  boolean	ManLiftParked; // @Metadata=(Units="unitless",Description="ManLiftParked")
	  boolean	STO_and_brake_Azimuth; // @Metadata=(Units="unitless",Description="STO_and_brake_Azimuth")
	  boolean	STO_and_brake_Elevation; // @Metadata=(Units="unitless",Description="STO_and_brake_Elevation")
	  boolean	STO_AZCW; // @Metadata=(Units="unitless",Description="STO_AZCW")
	  boolean	STO_CCW; // @Metadata=(Units="unitless",Description="STO_CCW")
	  boolean	STO_Balancing_System; // @Metadata=(Units="unitless",Description="STO_Balancing_System")
	  boolean	STO_Mirror_Cover; // @Metadata=(Units="unitless",Description="STO_Mirror_Cover")
	  boolean	STO_Locking_pins; // @Metadata=(Units="unitless",Description="STO_Locking_pins")
	  boolean	STO_Deployable_Platforms; // @Metadata=(Units="unitless",Description="STO_Deployable_Platforms")
	  boolean	Platform_extensions; // @Metadata=(Units="unitless",Description="Platform_extensions")
	  boolean	Phase_Cutoff_power; // @Metadata=(Units="unitless",Description="Phase_Cutoff_power")
	  boolean	Phase_Discharge_capacitors; // @Metadata=(Units="unitless",Description="Phase_Discharge_capacitors")
	  boolean	SKF_Pressure_Off; // @Metadata=(Units="unitless",Description="SKF_Pressure_Off")
	  boolean	CCW_Pull_Cord; // @Metadata=(Units="unitless",Description="CCW_Pull_Cord")
	  boolean	Emergency_to_GIS; // @Metadata=(Units="unitless",Description="Emergency_to_GIS")
	  boolean	TMA_Brakes_Failed; // @Metadata=(Units="unitless",Description="TMA_Brakes_Failed")
	  boolean	MCS_Failed; // @Metadata=(Units="unitless",Description="MCS_Failed")
	  boolean	Access_door_1_ladder_parker_position; // @Metadata=(Units="unitless",Description="Access_door_1_ladder_parker_position")
	  boolean	Access_door_2_ladder_parker_position; // @Metadata=(Units="unitless",Description="Access_door_2_ladder_parker_position")
	  boolean	AZ_platform_access_Door_1_switch; // @Metadata=(Units="unitless",Description="AZ_platform_access_Door_1_switch")
	  boolean	AZ_platform_access_Door_2_switch; // @Metadata=(Units="unitless",Description="AZ_platform_access_Door_2_switch")
	  boolean	Hath_switch_1; // @Metadata=(Units="unitless",Description="Hath_switch_1")
	  boolean	Hath_switch_2; // @Metadata=(Units="unitless",Description="Hath_switch_2")
	  boolean	Hath_switch_3; // @Metadata=(Units="unitless",Description="Hath_switch_3")
	  boolean	Hath_switch_4; // @Metadata=(Units="unitless",Description="Hath_switch_4")
	  boolean	Mirror_cover_1_assembly_locked_manual_switch_off; // @Metadata=(Units="unitless",Description="Mirror_cover_1_assembly_locked_manual_switch_off")
	  boolean	Mirror_cover_2_assembly_locked_manual_switch_off; // @Metadata=(Units="unitless",Description="Mirror_cover_2_assembly_locked_manual_switch_off")
	  boolean	Phase_Capacitor_cabinet_1_Door_Switch_1_9; // @Metadata=(Units="unitless",Description="Phase_Capacitor_cabinet_1_Door_Switch_1_9")
	  boolean	Phase_Capacitor_cabinet_2_Door_Switch_1_9; // @Metadata=(Units="unitless",Description="Phase_Capacitor_cabinet_2_Door_Switch_1_9")
	  boolean	Phase_Capacitor_cabinet_3_Door_Switch_1_9; // @Metadata=(Units="unitless",Description="Phase_Capacitor_cabinet_3_Door_Switch_1_9")
	  boolean	Phase_Capacitor_cabinet_4_Door_Switch_1_9; // @Metadata=(Units="unitless",Description="Phase_Capacitor_cabinet_4_Door_Switch_1_9")
	  boolean	Phase_Capacitor_cabinet_5_Door_Switch_1_9; // @Metadata=(Units="unitless",Description="Phase_Capacitor_cabinet_5_Door_Switch_1_9")
	  boolean	Phase_Capacitor_cabinet_6_Door_Switch_1_9; // @Metadata=(Units="unitless",Description="Phase_Capacitor_cabinet_6_Door_Switch_1_9")
	  boolean	Phase_Capacitor_cabinet_7_Door_Switch_1_9; // @Metadata=(Units="unitless",Description="Phase_Capacitor_cabinet_7_Door_Switch_1_9")
	  boolean	Phase_Capacitor_cabinet_8_Door_Switch_1_9; // @Metadata=(Units="unitless",Description="Phase_Capacitor_cabinet_8_Door_Switch_1_9")
	  boolean	ETPB_AZCW_handrail_middle_floor_1; // @Metadata=(Units="unitless",Description="ETPB_AZCW_handrail_middle_floor_1")
	  boolean	ETPB_AZCW_handrail_middle_floor_2; // @Metadata=(Units="unitless",Description="ETPB_AZCW_handrail_middle_floor_2")
	  boolean	ETPB_AZCW_handrail_middle_floor_3; // @Metadata=(Units="unitless",Description="ETPB_AZCW_handrail_middle_floor_3")
	  boolean	ETPB_AZCW_handrail_top_floor_1; // @Metadata=(Units="unitless",Description="ETPB_AZCW_handrail_top_floor_1")
	  boolean	ETPB_AZCW_handrail_top_floor_2; // @Metadata=(Units="unitless",Description="ETPB_AZCW_handrail_top_floor_2")
	  boolean	ETPB_AZCW_handrail_top_floor_3; // @Metadata=(Units="unitless",Description="ETPB_AZCW_handrail_top_floor_3")
	  boolean	ETPB_Azimuth_area_XPos_beam_1; // @Metadata=(Units="unitless",Description="ETPB_Azimuth_area_XPos_beam_1")
	  boolean	ETPB_Azimuth_area_XPos_beam_2; // @Metadata=(Units="unitless",Description="ETPB_Azimuth_area_XPos_beam_2")
	  boolean	ETPB_Azimuth_area_XPos_beam_3; // @Metadata=(Units="unitless",Description="ETPB_Azimuth_area_XPos_beam_3")
	  boolean	ETPB_Azimuth_area_XNeg_beam_1; // @Metadata=(Units="unitless",Description="ETPB_Azimuth_area_XNeg_beam_1")
	  boolean	ETPB_Azimuth_area_XNeg_beam_2; // @Metadata=(Units="unitless",Description="ETPB_Azimuth_area_XNeg_beam_2")
	  boolean	ETPB_Azimuth_area_XNeg_beam_3; // @Metadata=(Units="unitless",Description="ETPB_Azimuth_area_XNeg_beam_3")
	  boolean	ETPB_Azimuth_stair_XPos_section_1; // @Metadata=(Units="unitless",Description="ETPB_Azimuth_stair_XPos_section_1")
	  boolean	ETPB_Azimuth_stair_XPos_section_2; // @Metadata=(Units="unitless",Description="ETPB_Azimuth_stair_XPos_section_2")
	  boolean	ETPB_Azimuth_stair_XPos_section_3; // @Metadata=(Units="unitless",Description="ETPB_Azimuth_stair_XPos_section_3")
	  boolean	ETPB_Azimuth_stair_XNeg_section_1; // @Metadata=(Units="unitless",Description="ETPB_Azimuth_stair_XNeg_section_1")
	  boolean	ETPB_Azimuth_stair_XNeg_section_2; // @Metadata=(Units="unitless",Description="ETPB_Azimuth_stair_XNeg_section_2")
	  boolean	ETPB_Azimuth_stair_XNeg_section_3; // @Metadata=(Units="unitless",Description="ETPB_Azimuth_stair_XNeg_section_3")
	  boolean	ETPB_Deployable_platform_XPos; // @Metadata=(Units="unitless",Description="ETPB_Deployable_platform_XPos")
	  boolean	ETPB_Deployable_platform_XNeg; // @Metadata=(Units="unitless",Description="ETPB_Deployable_platform_XNeg")
	  boolean	ETPB_Elevation_XPos_pylon_1; // @Metadata=(Units="unitless",Description="ETPB_Elevation_XPos_pylon_1")
	  boolean	ETPB_Elevation_XPos_pylon_2; // @Metadata=(Units="unitless",Description="ETPB_Elevation_XPos_pylon_2")
	  boolean	ETPB_Elevation_XPos_TEA_1; // @Metadata=(Units="unitless",Description="ETPB_Elevation_XPos_TEA_1")
	  boolean	ETPB_Elevation_XPos_TEA_2; // @Metadata=(Units="unitless",Description="ETPB_Elevation_XPos_TEA_2")
	  boolean	ETPB_Elevation_XNeg_pylon_1; // @Metadata=(Units="unitless",Description="ETPB_Elevation_XNeg_pylon_1")
	  boolean	ETPB_Elevation_XNeg_pylon_2; // @Metadata=(Units="unitless",Description="ETPB_Elevation_XNeg_pylon_2")
	  boolean	ETPB_Elevation_XNeg_TEA_3; // @Metadata=(Units="unitless",Description="ETPB_Elevation_XNeg_TEA_3")
	  boolean	ETPB_Elevation_XNeg_TEA_4; // @Metadata=(Units="unitless",Description="ETPB_Elevation_XNeg_TEA_4")
	  boolean	ETPB_Elevation_ring_XPos_section_1; // @Metadata=(Units="unitless",Description="ETPB_Elevation_ring_XPos_section_1")
	  boolean	ETPB_Elevation_ring_XPos_section_2; // @Metadata=(Units="unitless",Description="ETPB_Elevation_ring_XPos_section_2")
	  boolean	ETPB_Elevation_ring_XPos_section_3; // @Metadata=(Units="unitless",Description="ETPB_Elevation_ring_XPos_section_3")
	  boolean	ETPB_Elevation_ring_XNeg_section_1; // @Metadata=(Units="unitless",Description="ETPB_Elevation_ring_XNeg_section_1")
	  boolean	ETPB_Elevation_ring_XNeg_section_2; // @Metadata=(Units="unitless",Description="ETPB_Elevation_ring_XNeg_section_2")
	  boolean	ETPB_Elevation_ring_XNeg_section_3; // @Metadata=(Units="unitless",Description="ETPB_Elevation_ring_XNeg_section_3")
	  boolean	ETPB_Handdeld_emergency_3; // @Metadata=(Units="unitless",Description="ETPB_Handdeld_emergency_3")
	  boolean	ETPB_Handdeld_emergency_4; // @Metadata=(Units="unitless",Description="ETPB_Handdeld_emergency_4")
	  boolean	ETPB_Handheld_emergency_1; // @Metadata=(Units="unitless",Description="ETPB_Handheld_emergency_1")
	  boolean	ETPB_Handheld_emergency_2; // @Metadata=(Units="unitless",Description="ETPB_Handheld_emergency_2")
	  boolean	ETPB_MCS_Cabinet; // @Metadata=(Units="unitless",Description="ETPB_MCS_Cabinet")
	  boolean	ETPB_Phase_cabinet; // @Metadata=(Units="unitless",Description="ETPB_Phase_cabinet")
	  boolean	Azimuth_Cable_Wrap_Negative_limit_switch; // @Metadata=(Units="unitless",Description="Azimuth_Cable_Wrap_Negative_limit_switch")
	  boolean	Azimuth_Cable_Wrap_Positive_limit_switch; // @Metadata=(Units="unitless",Description="Azimuth_Cable_Wrap_Positive_limit_switch")
	  boolean	Azimuth_Negative__power_off_limit_switch; // @Metadata=(Units="unitless",Description="Azimuth_Negative__power_off_limit_switch")
	  boolean	Azimuth_positive__power_off_limit_switch; // @Metadata=(Units="unitless",Description="Azimuth_positive__power_off_limit_switch")
	  boolean	CCW_Movement_Negative_limit__pull_cord_; // @Metadata=(Units="unitless",Description="CCW_Movement_Negative_limit__pull_cord_")
	  boolean	CCW_Movement_Positive_limit__pull_cord_; // @Metadata=(Units="unitless",Description="CCW_Movement_Positive_limit__pull_cord_")
	  boolean	Elevation_Negative_power_off_limit_switch; // @Metadata=(Units="unitless",Description="Elevation_Negative_power_off_limit_switch")
	  boolean	Elevation_Positive_power_off_limit_switch; // @Metadata=(Units="unitless",Description="Elevation_Positive_power_off_limit_switch")
	  boolean	Hard_Stop_1_topple_block_LS1; // @Metadata=(Units="unitless",Description="Hard_Stop_1_topple_block_LS1")
	  boolean	Hard_Stop_2_topple_block_LS1; // @Metadata=(Units="unitless",Description="Hard_Stop_2_topple_block_LS1")
	  boolean	Handheld_1_Bypass_Pushbutton; // @Metadata=(Units="unitless",Description="Handheld_1_Bypass_Pushbutton")
	  boolean	Handheld_1_Enable_Pushbutton; // @Metadata=(Units="unitless",Description="Handheld_1_Enable_Pushbutton")
	  boolean	Handheld_2_Bypass_Pushbutton; // @Metadata=(Units="unitless",Description="Handheld_2_Bypass_Pushbutton")
	  boolean	Handheld_2_Enable_Pushbutton; // @Metadata=(Units="unitless",Description="Handheld_2_Enable_Pushbutton")
	  boolean	Handheld_3_Bypass_Pushbutton; // @Metadata=(Units="unitless",Description="Handheld_3_Bypass_Pushbutton")
	  boolean	Handheld_3_Enable_Pushbutton; // @Metadata=(Units="unitless",Description="Handheld_3_Enable_Pushbutton")
	  boolean	Handheld_4_Bypass_Pushbutton; // @Metadata=(Units="unitless",Description="Handheld_4_Bypass_Pushbutton")
	  boolean	Handheld_4_Enable_Pushbutton; // @Metadata=(Units="unitless",Description="Handheld_4_Enable_Pushbutton")
	  boolean	Deployable_Platform_1_Extension_1_Inserted_Position; // @Metadata=(Units="unitless",Description="Deployable_Platform_1_Extension_1_Inserted_Position")
	  boolean	Deployable_Platform_1_Extension_2_Inserted_Position; // @Metadata=(Units="unitless",Description="Deployable_Platform_1_Extension_2_Inserted_Position")
	  boolean	Deployable_Platform_1_Module_1_Parking_Position; // @Metadata=(Units="unitless",Description="Deployable_Platform_1_Module_1_Parking_Position")
	  boolean	Deployable_Platform_1_Module_2_Parking_Position; // @Metadata=(Units="unitless",Description="Deployable_Platform_1_Module_2_Parking_Position")
	  boolean	Deployable_Platform_2_Extension_1_Inserted_Position; // @Metadata=(Units="unitless",Description="Deployable_Platform_2_Extension_1_Inserted_Position")
	  boolean	Deployable_Platform_2_Extension_2_Inserted_Position; // @Metadata=(Units="unitless",Description="Deployable_Platform_2_Extension_2_Inserted_Position")
	  boolean	Deployable_Platform_2_Module_1_Parking_Position; // @Metadata=(Units="unitless",Description="Deployable_Platform_2_Module_1_Parking_Position")
	  boolean	Deployable_Platform_2_Module_2_Parking_Position; // @Metadata=(Units="unitless",Description="Deployable_Platform_2_Module_2_Parking_Position")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Safety_System_dabc781b 
struct Top_End_Chiller_e3a71ab8 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	TEC_Status_Chiller_1; // @Metadata=(Units="unitless",Description="TEC_Status_Chiller_1")
	  string	TEC_Status_Chiller_2; // @Metadata=(Units="unitless",Description="TEC_Status_Chiller_2")
	  string	TEC_Status_Cabinet_1; // @Metadata=(Units="unitless",Description="TEC_Status_Cabinet_1")
	  string	TEC_Status_Cabinet_2; // @Metadata=(Units="unitless",Description="TEC_Status_Cabinet_2")
	  string	TEC_Status_Cabinet_3; // @Metadata=(Units="unitless",Description="TEC_Status_Cabinet_3")
	  string	TEC_Status_Cabinet_4; // @Metadata=(Units="unitless",Description="TEC_Status_Cabinet_4")
	  string	TEC_Status_Cabinet_5; // @Metadata=(Units="unitless",Description="TEC_Status_Cabinet_5")
	  string	TEC_Status_Cabinet_6; // @Metadata=(Units="unitless",Description="TEC_Status_Cabinet_6")
	  string	TEC_Fan_Status_Cabinet_1; // @Metadata=(Units="unitless",Description="TEC_Fan_Status_Cabinet_1")
	  string	TEC_Fan_Status_Cabinet_2; // @Metadata=(Units="unitless",Description="TEC_Fan_Status_Cabinet_2")
	  string	TEC_Fan_Status_Cabinet_3; // @Metadata=(Units="unitless",Description="TEC_Fan_Status_Cabinet_3")
	  string	TEC_Fan_Status_Cabinet_4; // @Metadata=(Units="unitless",Description="TEC_Fan_Status_Cabinet_4")
	  string	TEC_Fan_Status_Cabinet_5; // @Metadata=(Units="unitless",Description="TEC_Fan_Status_Cabinet_5")
	  string	TEC_Fan_Status_Cabinet_6; // @Metadata=(Units="unitless",Description="TEC_Fan_Status_Cabinet_6")
	  string	TEC_Status_Chiller_1_Valve; // @Metadata=(Units="unitless",Description="TEC_Status_Chiller_1_Valve")
	  string	TEC_Status_Chiller_2_Valve; // @Metadata=(Units="unitless",Description="TEC_Status_Chiller_2_Valve")
	  string	TEC_Status_Fan_11; // @Metadata=(Units="unitless",Description="TEC_Status_Fan_11")
	  string	TEC_Status_Fan_12; // @Metadata=(Units="unitless",Description="TEC_Status_Fan_12")
	  string	TEC_Status_Fan_13; // @Metadata=(Units="unitless",Description="TEC_Status_Fan_13")
	  string	TEC_Status_Fan_14; // @Metadata=(Units="unitless",Description="TEC_Status_Fan_14")
	  string	TEC_Status_Fan_31; // @Metadata=(Units="unitless",Description="TEC_Status_Fan_31")
	  string	TEC_Status_Fan_32; // @Metadata=(Units="unitless",Description="TEC_Status_Fan_32")
	  string	TEC_Status_Fan_33; // @Metadata=(Units="unitless",Description="TEC_Status_Fan_33")
	  string	TEC_Status_Fan_34; // @Metadata=(Units="unitless",Description="TEC_Status_Fan_34")
	  double	TEC_Temperature_Area_1; // @Metadata=(Units="deg_C",Description="TEC_Temperature_Area_1")
	  double	TEC_Temperature_Area_2; // @Metadata=(Units="deg_C",Description="TEC_Temperature_Area_2")
	  double	TEC_Temperature_Area_3; // @Metadata=(Units="deg_C",Description="TEC_Temperature_Area_3")
	  double	TEC_Temperature_Area_4; // @Metadata=(Units="deg_C",Description="TEC_Temperature_Area_4")
	  double	TEC_Temperature_Area_5; // @Metadata=(Units="deg_C",Description="TEC_Temperature_Area_5")
	  double	TEC_Internal_Humidity_Cabinet_1; // @Metadata=(Units="unitless",Description="TEC_Internal_Humidity_Cabinet_1")
	  double	TEC_Internal_Humidity_Cabinet_2; // @Metadata=(Units="unitless",Description="TEC_Internal_Humidity_Cabinet_2")
	  double	TEC_Internal_Humidity_Cabinet_3; // @Metadata=(Units="unitless",Description="TEC_Internal_Humidity_Cabinet_3")
	  double	TEC_Internal_Humidity_Cabinet_4; // @Metadata=(Units="unitless",Description="TEC_Internal_Humidity_Cabinet_4")
	  double	TEC_Internal_Humidity_Cabinet_5; // @Metadata=(Units="unitless",Description="TEC_Internal_Humidity_Cabinet_5")
	  double	TEC_Internal_Humidity_Cabinet_6; // @Metadata=(Units="unitless",Description="TEC_Internal_Humidity_Cabinet_6")
	  double	TEC_Internal_Temperature_Cabinet_1; // @Metadata=(Units="deg_C",Description="TEC_Internal_Temperature_Cabinet_1")
	  double	TEC_Internal_Temperature_Cabinet_2; // @Metadata=(Units="deg_C",Description="TEC_Internal_Temperature_Cabinet_2")
	  double	TEC_Internal_Temperature_Cabinet_3; // @Metadata=(Units="deg_C",Description="TEC_Internal_Temperature_Cabinet_3")
	  double	TEC_Internal_Temperature_Cabinet_4; // @Metadata=(Units="deg_C",Description="TEC_Internal_Temperature_Cabinet_4")
	  double	TEC_Internal_Temperature_Cabinet_5; // @Metadata=(Units="deg_C",Description="TEC_Internal_Temperature_Cabinet_5")
	  double	TEC_Internal_Temperature_Cabinet_6; // @Metadata=(Units="deg_C",Description="TEC_Internal_Temperature_Cabinet_6")
	  double	TEC_Surface_Temperature_Cabinet_1; // @Metadata=(Units="deg_C",Description="TEC_Surface_Temperature_Cabinet_1")
	  double	TEC_Surface_Temperature_Cabinet_2; // @Metadata=(Units="deg_C",Description="TEC_Surface_Temperature_Cabinet_2")
	  double	TEC_Surface_Temperature_Cabinet_3; // @Metadata=(Units="deg_C",Description="TEC_Surface_Temperature_Cabinet_3")
	  double	TEC_Surface_Temperature_Cabinet_4; // @Metadata=(Units="deg_C",Description="TEC_Surface_Temperature_Cabinet_4")
	  double	TEC_Surface_Temperature_Cabinet_5; // @Metadata=(Units="deg_C",Description="TEC_Surface_Temperature_Cabinet_5")
	  double	TEC_Surface_Temperature_Cabinet_6; // @Metadata=(Units="deg_C",Description="TEC_Surface_Temperature_Cabinet_6")
	  double	TEC_Humidity_Area_1; // @Metadata=(Units="unitless",Description="TEC_Humidity_Area_1")
	  double	TEC_Humidity_Area_2; // @Metadata=(Units="unitless",Description="TEC_Humidity_Area_2")
	  double	TEC_Humidity_Area_3; // @Metadata=(Units="unitless",Description="TEC_Humidity_Area_3")
	  double	TEC_Humidity_Area_4; // @Metadata=(Units="unitless",Description="TEC_Humidity_Area_4")
	  double	TEC_Humidity_Area_5; // @Metadata=(Units="unitless",Description="TEC_Humidity_Area_5")
	  double	TEC_Temperature_Fan_13_Input; // @Metadata=(Units="deg_C",Description="TEC_Temperature_Fan_13_Input")
	  double	TEC_Temperature_Fan_14_Input; // @Metadata=(Units="deg_C",Description="TEC_Temperature_Fan_14_Input")
	  double	TEC_Regulation_Chiller_1_Valve; // @Metadata=(Units="deg_C",Description="TEC_Regulation_Chiller_1_Valve")
	  double	TEC_Regulation_Chiller_2_Valve; // @Metadata=(Units="deg_C",Description="TEC_Regulation_Chiller_2_Valve")
	  double	timestamp; // @Metadata=(Units="second",Description="timestamp")
	};
#pragma keylist Top_End_Chiller_e3a71ab8 
struct command_abort_c383f55a {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	value; // @Metadata=(Units="unitless",Description="Not used")
	};
#pragma keylist command_abort_c383f55a 
struct command_clearerror_326886b5 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	state; // @Metadata=(Units="unitless",Description="Unused.")
	};
#pragma keylist command_clearerror_326886b5 
struct command_closeMirrorCover_f75a2583 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	state; // @Metadata=(Units="unitless",Description="Ignored.")
	};
#pragma keylist command_closeMirrorCover_f75a2583 
struct command_configure_ae674263 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	spec_id; // @Metadata=(Units="unitless",Description="Configuration dentifier.")
	};
#pragma keylist command_configure_ae674263 
struct command_disable_f845b20c {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	value; // @Metadata=(Units="unitless",Description="Not used")
	};
#pragma keylist command_disable_f845b20c 
struct command_disableCamWrap_3afbb513 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	state; // @Metadata=(Units="unitless",Description="Unsused.")
	};
#pragma keylist command_disableCamWrap_3afbb513 
struct command_enable_00617bac {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	value; // @Metadata=(Units="unitless",Description="Not used")
	};
#pragma keylist command_enable_00617bac 
struct command_enableCamWrap_9341fccc {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	state; // @Metadata=(Units="unitless",Description="Unused.")
	};
#pragma keylist command_enableCamWrap_9341fccc 
struct command_enterControl_24dcd1c6 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	value; // @Metadata=(Units="unitless",Description="Not used")
	};
#pragma keylist command_enterControl_24dcd1c6 
struct command_exitControl_1798cf8d {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	value; // @Metadata=(Units="unitless",Description="Not used")
	};
#pragma keylist command_exitControl_1798cf8d 
struct command_moveToTarget_02a5ea21 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	az_angle; // @Metadata=(Units="degree",Description="Azimuth angle")
	  double	el_angle; // @Metadata=(Units="degree",Description="Elevation angle")
	  string	cablewrap_orientation; // @Metadata=(Units="unitless",Description="Cable Wrap orientation: Clockwise(CW); Counterclockwise(CCW)")
	};
#pragma keylist command_moveToTarget_02a5ea21 
struct command_openMirrorCover_f93a1a94 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	state; // @Metadata=(Units="unitless",Description="Unused")
	};
#pragma keylist command_openMirrorCover_f93a1a94 
struct command_setAuthList_4098513e {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	authorizedUsers; // @Metadata=(Units="unitless",Description="Comma seperated list of authorized users currently allowed to command this CSC;")
	  string	nonAuthorizedCSCs; // @Metadata=(Units="unitless",Description="Comma seperated list of CSC's not currently allowed to command this CSC;")
	};
#pragma keylist command_setAuthList_4098513e 
struct command_setLogLevel_007f793f {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	level; // @Metadata=(Units="unitless",Description="Logging level; as a Python logging level: error=40; warning=30; info=20; debug=10.")
	};
#pragma keylist command_setLogLevel_007f793f 
struct command_setValue_300cce68 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string<256>	parametersAndValues; // @Metadata=(Units="unitless",Description="List of parameters and their values as a Json string")
	};
#pragma keylist command_setValue_300cce68 
struct command_standby_53299c8a {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	value; // @Metadata=(Units="unitless",Description="Not used")
	};
#pragma keylist command_standby_53299c8a 
struct command_start_58b61337 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string<256>	settingsToApply; // @Metadata=(Units="unitless",Description="Name of the selected settings set")
	};
#pragma keylist command_start_58b61337 
struct command_trackTarget_562d04aa {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	az_angle; // @Metadata=(Units="degree",Description="Azimuth angle")
	  double	az_velocity; // @Metadata=(Units="degree/second",Description="Azimuth velocity")
	  double	el_angle; // @Metadata=(Units="degree",Description=" Elevation angle")
	  double	el_velocity; // @Metadata=(Units="degree/second",Description=" Elevation velocity")
	  double	time; // @Metadata=(Units="second",Description="TAI date at which the commanded positions and velocities apply; as unix time.")
	  string	cablewrap_orientation; // @Metadata=(Units="unitless",Description="Cable Wrap orientation: Clockwise(CW); Counterclockwise(CCW)")
	};
#pragma keylist command_trackTarget_562d04aa 
struct logevent_appliedSettingsMatchStart_54e1e5c0 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	appliedSettingsMatchStartIsTrue; // @Metadata=(Units="unitless",Description="True when the configuration matches the start conditions")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_appliedSettingsMatchStart_54e1e5c0 
struct logevent_authList_9a339f4a {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	authorizedUsers; // @Metadata=(Units="unitless",Description="Comma seperated list of authorized users currently allowed to command this CSC.")
	  string	nonAuthorizedCSCs; // @Metadata=(Units="unitless",Description="Comma seperated list of CSC's not currently allowed to command this CSC.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_authList_9a339f4a 
struct logevent_errorCode_cded5a6c {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	errorCode; // @Metadata=(Units="unitless",Description="A numeric error code")
	  string	errorReport; // @Metadata=(Units="unitless",Description="An string providing detailed information about the error")
	  string	traceback; // @Metadata=(Units="unitless",Description="An optional stack trace of the error condition")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_errorCode_cded5a6c 
struct logevent_heartbeat_a499b5c4 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	heartbeat; // @Metadata=(Units="unitless",Description="Beats the drum.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_heartbeat_a499b5c4 
struct logevent_logLevel_711c3dce {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	level; // @Metadata=(Units="unitless",Description="Current logging level; a Python logging level: error=40; warning=30; info=20; debug=10.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_logLevel_711c3dce 
struct logevent_logMessage_0a83e8e8 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	name; // @Metadata=(Units="unitless",Description="Log name.")
	  long	level; // @Metadata=(Units="unitless",Description="Message level; a Python logging level: error=40; warning=30; info=20; debug=10.")
	  string	message; // @Metadata=(Units="unitless",Description="Log message.")
	  string	traceback; // @Metadata=(Units="unitless",Description="Exception traceback; "" if not an exception.")
	  string	filePath; // @Metadata=(Units="unitless",Description="Path to source file.")
	  string	functionName; // @Metadata=(Units="unitless",Description="Function or method name.")
	  long	lineNumber; // @Metadata=(Units="unitless",Description="Line number in the file specified by filePath.")
	  long	process; // @Metadata=(Units="unitless",Description="Process ID.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_logMessage_0a83e8e8 
struct logevent_mountError_ded165ae {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	id; // @Metadata=(Units="unitless",Description="Identifier of the error")
	  string	text; // @Metadata=(Units="unitless",Description="The error info")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_mountError_ded165ae 
struct logevent_mountInPosition_f983cc26 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	inposition; // @Metadata=(Units="unitless",Description="Whether the mount is in position or not")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_mountInPosition_f983cc26 
struct logevent_mountState_6bd0a499 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	id; // @Metadata=(Units="unitless",Description="Identifier of the state")
	  string	text; // @Metadata=(Units="unitless",Description="The state of the state machine")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_mountState_6bd0a499 
struct logevent_mountWarning_b38e25f1 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	id; // @Metadata=(Units="unitless",Description="Identifier of the warning")
	  string	text; // @Metadata=(Units="unitless",Description="The warning info")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_mountWarning_b38e25f1 
struct logevent_settingVersions_e97cc0eb {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	recommendedSettingsVersion; // @Metadata=(Units="unitless",Description="List of comma seperated recomended versions of settings sets")
	  string	recommendedSettingsLabels; // @Metadata=(Units="unitless",Description="List of comma seperated names of settings sets")
	  string	settingsUrl; // @Metadata=(Units="unitless",Description="The URL where the settings sets definitions can be found")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_settingVersions_e97cc0eb 
struct logevent_settingsApplied_a105eb6b {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string<256>	settingsVersion; // @Metadata=(Units="unitless",Description="The SHA or name corresponding to the published configuration")
	  string	otherSettingsEvents; // @Metadata=(Units="unitless",Description="A comma delimited list of other specific CSC configuration events. This may be blank if no other CSC specific events are necessary")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_settingsApplied_a105eb6b 
struct logevent_simulationMode_67e44814 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	mode; // @Metadata=(Units="unitless",Description="Current simulation mode; 0 for normal operation (no simulation); other supported values are specific to each CSC.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_simulationMode_67e44814 
struct logevent_softwareVersions_945b5e2b {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string<256>	salVersion; // @Metadata=(Units="unitless",Description="This is the current version of SAL generation")
	  string<256>	xmlVersion; // @Metadata=(Units="unitless",Description="This is the current version of CSC XML")
	  string<256>	openSpliceVersion; // @Metadata=(Units="unitless",Description="This is the current version of OpenSplice")
	  string<256>	cscVersion; // @Metadata=(Units="unitless",Description="This is the top-level version of the CSC")
	  string	subsystemVersions; // @Metadata=(Units="unitless",Description="A comma delimited list of key=value pairs relating subsystem name (key) to its version number (value). This may be left blank if there are no subsystems within a CSC")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_softwareVersions_945b5e2b 
struct logevent_summaryState_6f0fcc02 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp;    //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp;    //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long	private_seqNum;    //private // @Metadata=(Units="unitless",Description="Sequence number")
	  string<128>	private_identity;    //private // @Metadata=(Units="unitless",Description="Identity of originator")
	  long	private_origin;    //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long	private_host;    //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	summaryState; // @Metadata=(Units="unitless",Description="High level state machine state identifier")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_summaryState_6f0fcc02 
struct ackcmd_99f86545 {  // @Metadata=(Description="")
  string<8>	private_revCode; //private
  double	private_sndStamp;    //private
  double	private_rcvStamp;    //private
  long	private_seqNum;    //private
  string<128>	private_identity;    //private
  long	private_origin;    //private
  long	private_host;    //private
	  long	ack;
	  long	error;
	  string<256>	result;
	  long	host;
	  string	identity;
	  long	origin;
	  long	cmdtype;
	  double	timeout;
	};
#pragma keylist ackcmd_99f86545 
};

